@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -205,13 +205,21 @@ define([
          * @private
          */
         hasPoint: function (x, y) {
-            var prec = this.board.options.precision.hasPoint / (this.board.unitX),
+            var prec = this.board.options.precision.hasPoint,
                 mp = this.center.coords.usrCoords,
                 p = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board),
                 r = this.Radius(),
-                dist = Math.sqrt((mp[1] - p.usrCoords[1]) * (mp[1] - p.usrCoords[1]) + (mp[2] - p.usrCoords[2]) * (mp[2] - p.usrCoords[2]));
+                dx, dy, dist;
 
-            if (this.visProp.hasinnerpoints) {
+                dx = mp[1] - p.usrCoords[1];
+                dy = mp[2] - p.usrCoords[2];
+                dist = Math.sqrt(dx * dx + dy * dy);
+
+                // We have to use usrCoords, since Radius is available in usrCoords only.
+                prec += Type.evaluate(this.visProp.strokewidth) * 0.5;
+                prec /= Math.sqrt(this.board.unitX * this.board.unitY);
+
+            if (Type.evaluate(this.visProp.hasinnerpoints)) {
                 return (dist < r + prec);
             }
 
@@ -320,7 +328,7 @@ define([
          */
         update: function () {
             if (this.needsUpdate) {
-                if (this.visProp.trace) {
+                if (Type.evaluate(this.visProp.trace)) {
                     this.cloneToBackground(true);
                 }
 
@@ -381,36 +389,45 @@ define([
         updateRenderer: function () {
             var wasReal;
 
-            if (this.needsUpdate && this.visProp.visible) {
+            if (!this.needsUpdate) {
+                return this;
+            }
+
+            if (this.visPropCalc.visible) {
                 wasReal = this.isReal;
                 this.isReal = (!isNaN(this.center.coords.usrCoords[1] + this.center.coords.usrCoords[2] + this.Radius())) && this.center.isReal;
 
-                if (this.isReal) {
-                    if (wasReal !== this.isReal) {
-                        this.board.renderer.show(this);
-
-                        if (this.hasLabel && this.label.visProp.visible) {
-                            this.board.renderer.show(this.label);
-                        }
-                    }
-                    this.board.renderer.updateEllipse(this);
-                } else {
-                    if (wasReal !== this.isReal) {
-                        this.board.renderer.hide(this);
-
-                        if (this.hasLabel && this.label.visProp.visible) {
-                            this.board.renderer.hide(this.label);
-                        }
-                    }
+                if (wasReal && !this.isReal) {
+                    this.updateVisibility(false);
                 }
-                this.needsUpdate = false;
+            }
+
+            // Update the position
+            if (this.visPropCalc.visible) {
+                this.board.renderer.updateEllipse(this);
             }
 
             // Update the label if visible.
-            if (this.hasLabel && this.label.visProp.visible && this.isReal) {
+            if (this.hasLabel && this.visPropCalc.visible && this.label &&
+                this.label.visPropCalc.visible && this.isReal) {
+
                 this.label.update();
                 this.board.renderer.updateText(this.label);
             }
+
+            // Update rendNode display
+            this.setDisplayRendNode();
+            // if (this.visPropCalc.visible !== this.visPropOld.visible) {
+            //     this.board.renderer.display(this, this.visPropCalc.visible);
+            //     this.visPropOld.visible = this.visPropCalc.visible;
+            //
+            //     if (this.hasLabel) {
+            //         this.board.renderer.display(this.label, this.label.visPropCalc.visible);
+            //     }
+            // }
+
+            this.needsUpdate = false;
+            return this;
         },
 
         /**
@@ -489,7 +506,7 @@ define([
                 r = this.Radius(),
                 c = this.center.coords.usrCoords;
 
-            switch (this.visProp.label.position) {
+            switch (Type.evaluate(this.visProp.label.position)) {
             case 'lft':
                 x = c[1] - r;
                 y = c[2];
@@ -586,11 +603,11 @@ define([
 
         // see element.js
         snapToGrid: function () {
-            var forceIt = this.visProp.snaptogrid;
+            var forceIt = Type.evaluate(this.visProp.snaptogrid);
 
-            this.center.snapToGrid(forceIt);
+            this.center.handleSnapToGrid(forceIt, true);
             if (this.method === 'twoPoints') {
-                this.point2.snapToGrid(forceIt);
+                this.point2.handleSnapToGrid(forceIt, true);
             }
 
             return this;
@@ -598,7 +615,7 @@ define([
 
         // see element.js
         snapToPoints: function () {
-            var forceIt = this.visProp.snaptopoints;
+            var forceIt = Type.evaluate(this.visProp.snaptopoints);
 
             this.center.handleSnapToPoints(forceIt);
             if (this.method === 'twoPoints') {
@@ -708,7 +725,7 @@ define([
      * // Create another circle using the above circle
      * var p3 = board.create('point', [3.0, 2.0]),
      *     c2 = board.create('circle', [p3, c1]);
-     * </pre><div class="jxgbox"id="5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function() {
      *   var cex1_board = JXG.JSXGraph.initBoard('5f304d31-ef20-4a8e-9c0e-ea1a2b6c79e0', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -726,7 +743,7 @@ define([
      *
      * // Create another circle using the above circle
      * var c2 = board.create('circle', [function() { return [p1.X(), p1.Y() + 1];}, function() { return c1.Radius(); }]);
-     * </pre><div class="jxgbox"id="54165f60-93b9-441d-8979-ac5d0f193020" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="54165f60-93b9-441d-8979-ac5d0f193020" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function() {
      * var board = JXG.JSXGraph.initBoard('54165f60-93b9-441d-8979-ac5d0f193020', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -794,6 +811,11 @@ define([
         el.isDraggable = isDraggable;
         el.setParents(p);
         el.elType = 'circle';
+        for (i = 0; i < p.length; i++) {
+            if (Type.isPoint(p[i])) {
+                el.inherits.push(p[i]);
+            }
+        }
         return el;
     };
 
