@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -43,8 +43,8 @@ define(['jxg'], function (JXG) {
 
     var major = 0,
         minor = 99,
-        patch = 5,
-        add = false, // 'dev',
+        patch = 6,
+        add = false, //false, // 'dev',
         version = major + '.' + minor + '.' + patch + (add ? '-' + add : ''),
         constants;
 
