@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -79,7 +79,7 @@ define([
          * between numberPointsLow and numberPointsHigh.
          * It is set in {@link JXG.Curve#updateCurve}.
          */
-        this.numberPoints = this.visProp.numberpointshigh;
+        this.numberPoints = Type.evaluate(this.visProp.numberpointshigh);
 
         this.bezierDegree = 1;
 
@@ -155,7 +155,7 @@ define([
         minX: function () {
             var leftCoords;
 
-            if (this.visProp.curvetype === 'polar') {
+            if (Type.evaluate(this.visProp.curvetype) === 'polar') {
                 return 0;
             }
 
@@ -171,7 +171,7 @@ define([
         maxX: function () {
             var rightCoords;
 
-            if (this.visProp.curvetype === 'polar') {
+            if (Type.evaluate(this.visProp.curvetype) === 'polar') {
                 return 2 * Math.PI;
             }
             rightCoords = new Coords(Const.COORDS_BY_SCREEN, [this.board.canvasWidth, 0], this.board, false);
@@ -222,17 +222,28 @@ define([
          */
         hasPoint: function (x, y, start) {
             var t, checkPoint, len, invMat, c,
-                i, j, tX, tY, res, points, qdt,
-                steps = this.visProp.numberpointslow,
+                i, j, tX, tY,
+                res = [],
+                points, qdt,
+                steps = Type.evaluate(this.visProp.numberpointslow),
                 d = (this.maxX() - this.minX()) / steps,
-                prec = this.board.options.precision.hasPoint / this.board.unitX,
+                prec = this.board.options.precision.hasPoint,
                 dist = Infinity,
+                ux2, uy2,
+                ev_ct,
                 suspendUpdate = true;
 
             checkPoint = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board, false);
             x = checkPoint.usrCoords[1];
             y = checkPoint.usrCoords[2];
 
+            // We use usrCoords. Only in the final distance calculation
+            // screen coords are used
+            prec += Type.evaluate(this.visProp.strokewidth) * 0.5;
+            prec *= prec; // We do not want to take sqrt
+            ux2 = this.board.unitX * this.board.unitX;
+            uy2 = this.board.unitY * this.board.unitY;
+
             if (this.transformations.length > 0) {
                 /**
                  * Transform the mouse/touch coordinates
@@ -245,8 +256,9 @@ define([
                 y = c[2];
             }
 
-            if (this.visProp.curvetype === 'parameter' ||
-                    this.visProp.curvetype === 'polar') {
+            ev_ct = Type.evaluate(this.visProp.curvetype);
+            if (ev_ct === 'parameter' ||
+                    ev_ct === 'polar') {
 
                 prec = prec * prec;
 
@@ -255,22 +267,22 @@ define([
                     tX = this.X(t, suspendUpdate);
                     tY = this.Y(t, suspendUpdate);
 
-                    dist = (x - tX) * (x - tX) + (y - tY) * (y - tY);
+                    dist = (x - tX) * (x - tX) * ux2 + (y - tY) * (y - tY) * uy2;
 
-                    if (dist < prec) {
+                    if (dist <= prec) {
                         return true;
                     }
 
                     t += d;
                 }
-            } else if (this.visProp.curvetype === 'plot' ||
-                    this.visProp.curvetype === 'functiongraph') {
+            } else if (ev_ct === 'plot' ||
+                        ev_ct === 'functiongraph') {
 
                 if (!Type.exists(start) || start < 0) {
                     start = 0;
                 }
 
-                if (Type.exists(this.qdt) && this.visProp.useqdt && this.bezierDegree !== 3) {
+                if (Type.exists(this.qdt) && Type.evaluate(this.visProp.useqdt) && this.bezierDegree !== 3) {
                     qdt = this.qdt.query(new Coords(Const.COORDS_BY_USER, [x, y], this.board));
                     points = qdt.points;
                     len = points.length;
@@ -280,43 +292,41 @@ define([
                 }
 
                 for (i = start; i < len; i++) {
-                    res = [];
                     if (this.bezierDegree === 3) {
                         res.push(Geometry.projectCoordsToBeziersegment([1, x, y], this, i));
                     } else {
                         if (qdt) {
                             if (points[i].prev) {
-                                res.push(Geometry.projectCoordsToSegment(
+                                res = Geometry.projectCoordsToSegment(
                                     [1, x, y],
                                     points[i].prev.usrCoords,
                                     points[i].usrCoords
-                                ));
+                                );
                             }
 
                             // If the next point in the array is the same as the current points
                             // next neighbor we don't have to project it onto that segment because
                             // that will already be done in the next iteration of this loop.
                             if (points[i].next && points[i + 1] !== points[i].next) {
-                                res.push(Geometry.projectCoordsToSegment(
+                                res = Geometry.projectCoordsToSegment(
                                     [1, x, y],
                                     points[i].usrCoords,
                                     points[i].next.usrCoords
-                                ));
+                                );
                             }
                         } else {
-                            res.push(Geometry.projectCoordsToSegment(
+                            res = Geometry.projectCoordsToSegment(
                                 [1, x, y],
                                 points[i].usrCoords,
                                 points[i + 1].usrCoords
-                            ));
+                            );
                         }
                     }
 
-                    for (j = 0; j < res.length; j++) {
-                        if (res[j][1] >= 0 && res[j][1] <= 1 &&
-                                Geometry.distance([1, x, y], res[j][0], 3) <= prec) {
-                            return true;
-                        }
+                    if (res[1] >= 0 && res[1] <= 1 &&
+                        (x - res[0][1]) * (x - res[0][1]) * ux2 +
+                        (y - res[0][2]) * (y - res[0][2]) * uy2 <= prec) {
+                        return true;
                     }
                 }
                 return false;
@@ -346,7 +356,7 @@ define([
          */
         update: function () {
             if (this.needsUpdate) {
-                if (this.visProp.trace) {
+                if (Type.evaluate(this.visProp.trace)) {
                     this.cloneToBackground(true);
                 }
                 this.updateCurve();
@@ -362,37 +372,43 @@ define([
         updateRenderer: function () {
             var wasReal;
 
-            if (this.needsUpdate && this.visProp.visible) {
+            if (!this.needsUpdate) {
+                return this;
+            }
+
+            if (this.visPropCalc.visible) {
                 wasReal = this.isReal;
 
                 this.checkReal();
 
-                if (this.isReal || wasReal) {
-                    this.board.renderer.updateCurve(this);
-                }
-
-                if (this.isReal) {
-                    if (wasReal !== this.isReal) {
-                        this.board.renderer.show(this);
-                        if (this.hasLabel && this.label.visProp.visible) {
-                            this.board.renderer.show(this.label);
-                        }
-                    }
-                } else {
-                    if (wasReal !== this.isReal) {
-                        this.board.renderer.hide(this);
-                        if (this.hasLabel && this.label.visProp.visible) {
-                            this.board.renderer.hide(this.label);
-                        }
-                    }
-                }
-
-                // Update the label if visible.
-                if (this.hasLabel && Type.exists(this.label.visProp) && this.label.visProp.visible) {
-                    this.label.update();
-                    this.board.renderer.updateText(this.label);
+                if (wasReal && !this.isReal) {
+                    this.updateVisibility(false);
                 }
             }
+
+            if (this.visPropCalc.visible) {
+                this.board.renderer.updateCurve(this);
+            }
+
+            /* Update the label if visible. */
+            if (this.hasLabel && this.visPropCalc.visible && this.label &&
+                this.label.visPropCalc.visible && this.isReal) {
+
+                this.label.update();
+                this.board.renderer.updateText(this.label);
+            }
+
+            // Update rendNode display
+            this.setDisplayRendNode();
+            // if (this.visPropCalc.visible !== this.visPropOld.visible) {
+            //     this.board.renderer.display(this, this.visPropCalc.visible);
+            //     this.visPropOld.visible = this.visPropCalc.visible;
+            //
+            //     if (this.hasLabel) {
+            //         this.board.renderer.display(this.label, this.label.visPropCalc.visible);
+            //     }
+            // }
+
             this.needsUpdate = false;
             return this;
         },
@@ -578,7 +594,7 @@ define([
          *                         d[0] *= height/dl;
          *                         return mid+d[0]+0.1;
          *                     },
-         *                     function() { return "length="+B.Dist(A).toFixed(2); }
+         *                     function() { return "length=" + JXG.toFixed(B.Dist(A), 2); }
          *                 ]);
          *
          *
@@ -628,7 +644,7 @@ define([
          *                             d[0] *= height/dl;
          *                             return mid+d[0]+0.1;
          *                         },
-         *                         function() { return "length="+B.Dist(A).toFixed(2); }
+         *                         function() { return "length="+JXG.toFixed(B.Dist(A), 2); }
          *                     ]);
          *
          *
@@ -691,15 +707,15 @@ define([
                 }
             // continuous x data
             } else {
-                if (this.visProp.doadvancedplot) {
+                if (Type.evaluate(this.visProp.doadvancedplot)) {
                     this.updateParametricCurve(mi, ma, len);
-                } else if (this.visProp.doadvancedplotold) {
+                } else if (Type.evaluate(this.visProp.doadvancedplotold)) {
                     this.updateParametricCurveOld(mi, ma, len);
                 } else {
                     if (this.board.updateQuality === this.board.BOARD_QUALITY_HIGH) {
-                        this.numberPoints = this.visProp.numberpointshigh;
+                        this.numberPoints = Type.evaluate(this.visProp.numberpointshigh);
                     } else {
-                        this.numberPoints = this.visProp.numberpointslow;
+                        this.numberPoints = Type.evaluate(this.visProp.numberpointslow);
                     }
 
                     // It is possible, that the array length has increased.
@@ -708,7 +724,7 @@ define([
                 }
                 len = this.numberPoints;
 
-                if (this.visProp.useqdt && this.board.updateQuality === this.board.BOARD_QUALITY_HIGH) {
+                if (Type.evaluate(this.visProp.useqdt) && this.board.updateQuality === this.board.BOARD_QUALITY_HIGH) {
                     this.qdt = new QDT(this.board.getBoundingBox());
                     for (i = 0; i < this.points.length; i++) {
                         this.qdt.insert(this.points[i]);
@@ -728,11 +744,9 @@ define([
                 }
             }
 
-            if (this.visProp.curvetype !== 'plot' && this.visProp.rdpsmoothing) {
-//console.log("B", this.numberPoints);
+            if (Type.evaluate(this.visProp.curvetype) !== 'plot' && Type.evaluate(this.visProp.rdpsmoothing)) {
                 this.points = Numerics.RamerDouglasPeucker(this.points, 0.2);
                 this.numberPoints = this.points.length;
-//console.log("A", this.numberPoints);
             }
 
             return this;
@@ -1354,18 +1368,13 @@ define([
                 pa = new Coords(Const.COORDS_BY_USER, [0, 0], this.board, false),
                 pb = new Coords(Const.COORDS_BY_USER, [0, 0], this.board, false),
                 depth, delta;
-//var stime = new Date();
             if (this.board.updateQuality === this.board.BOARD_QUALITY_LOW) {
                 depth = 13;
-                delta = 1.2;
-
                 delta = 2;
                 this.smoothLevel = depth - 7;
                 this.jumpLevel = 5;
             } else {
                 depth = 17;
-                delta = 0.9;
-
                 delta = 2;
                 this.smoothLevel = depth - 7; // 9
                 this.jumpLevel = 3;
@@ -1387,11 +1396,8 @@ define([
             this._lastCrds = pa.copy('scrCoords');   //Used in _insertPoint
             this._plotRecursive(a, ta, b, tb, depth, delta);
             this.points.push(pb);
-//console.log("NUmber points", this.points.length, this.board.updateQuality, this.board.BOARD_QUALITY_LOW);
 
             this.numberPoints = this.points.length;
-//var etime = new Date();
-//console.log(this.name, this.numberPoints, etime.getTime() - stime.getTime(), this.board.updateQuality===this.board.BOARD_QUALITY_HIGH);
 
             return this;
         },
@@ -1608,7 +1614,7 @@ define([
                 bx = 0.95 * this.board.canvasWidth,
                 by = 0.95 * this.board.canvasHeight;
 
-            switch (this.visProp.label.position) {
+            switch (Type.evaluate(this.visProp.label.position)) {
             case 'ulft':
                 x = ax;
                 y = ay;
@@ -1802,7 +1808,7 @@ define([
      *                         function(t){ return 1-Math.cos(t);},
      *                         0, 2*Math.PI]
      *                     );
-     * </pre><div class="jxgbox"id="af9f818b-f3b6-4c4d-8c4c-e4a4078b726d" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="af9f818b-f3b6-4c4d-8c4c-e4a4078b726d" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var c1_board = JXG.JSXGraph.initBoard('af9f818b-f3b6-4c4d-8c4c-e4a4078b726d', {boundingbox: [-1, 5, 7, -1], axis: true, showcopyright: false, shownavigation: false});
      *   var graph1 = c1_board.create('curve', [function(t){ return t-Math.sin(t);},function(t){ return 1-Math.cos(t);},0, 2*Math.PI]);
@@ -1815,7 +1821,7 @@ define([
      *   var x = [0,1,2,3,4,5,6,7,8,9];
      *   var y = [9.2,1.3,7.2,-1.2,4.0,5.3,0.2,6.5,1.1,0.0];
      *   var graph = board.create('curve', [x,y], {dash:2});
-     * </pre><div class="jxgbox"id="7dcbb00e-b6ff-481d-b4a8-887f5d8c6a83" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="7dcbb00e-b6ff-481d-b4a8-887f5d8c6a83" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var c3_board = JXG.JSXGraph.initBoard('7dcbb00e-b6ff-481d-b4a8-887f5d8c6a83', {boundingbox: [-1,10,10,-1], axis: true, showcopyright: false, shownavigation: false});
      *   var x = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
@@ -1832,7 +1838,7 @@ define([
      *                         [1,0],
      *                         0, 2*Math.PI]
      *                     );
-     * </pre><div class="jxgbox"id="d0bc7a2a-8124-45ca-a6e7-142321a8f8c2" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="d0bc7a2a-8124-45ca-a6e7-142321a8f8c2" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var c2_board = JXG.JSXGraph.initBoard('d0bc7a2a-8124-45ca-a6e7-142321a8f8c2', {boundingbox: [-3,3,3,-3], axis: true, showcopyright: false, shownavigation: false});
      *   var a = c2_board.create('slider',[[0,2],[2,2],[0,1,2]]);
@@ -1852,7 +1858,7 @@ define([
      *  c = board.create('curve', JXG.Math.Numerics.bezier(p),
      *              {strokeColor:'red', name:"curve", strokeWidth:5, fixed: false}); // Draggable curve
      *  c.addParents(p);
-     * </pre><div class="jxgbox"id="7bcc6280-f6eb-433e-8281-c837c3387849" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="7bcc6280-f6eb-433e-8281-c837c3387849" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function(){
      *  var board, col, p, c;
@@ -1901,7 +1907,7 @@ define([
      *   var graph = board.create('functiongraph',
      *                        [function(x){ return 0.5*x*x-2*x;}, -2, 4]
      *                     );
-     * </pre><div class="jxgbox"id="efd432b5-23a3-4846-ac5b-b471e668b437" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="efd432b5-23a3-4846-ac5b-b471e668b437" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var alex1_board = JXG.JSXGraph.initBoard('efd432b5-23a3-4846-ac5b-b471e668b437', {boundingbox: [-3, 7, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var graph = alex1_board.create('functiongraph', [function(x){ return 0.5*x*x-2*x;}, -2, 4]);
@@ -1914,7 +1920,7 @@ define([
      *                         -2,
      *                         function(){return s.Value();}]
      *                     );
-     * </pre><div class="jxgbox"id="4a203a84-bde5-4371-ad56-44619690bb50" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="4a203a84-bde5-4371-ad56-44619690bb50" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var alex2_board = JXG.JSXGraph.initBoard('4a203a84-bde5-4371-ad56-44619690bb50', {boundingbox: [-3, 7, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var s = alex2_board.create('slider',[[0,4],[3,4],[-2,4,5]]);
@@ -2092,8 +2098,8 @@ define([
      *               {fillOpacity:0.4}
      *               );
      *   var g = board.create('functiongraph',[f, -2, 5]);
-     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + r.Value().toFixed(4); }]);
-     * </pre><div class="jxgbox"id="940f40cc-2015-420d-9191-c5d83de988cf" style="width: 300px; height: 300px;"></div>
+     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + JXG.toFixed(r.Value(), 4); }]);
+     * </pre><div class="jxgbox" id="940f40cc-2015-420d-9191-c5d83de988cf" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function(){
      *   var board = JXG.JSXGraph.initBoard('940f40cc-2015-420d-9191-c5d83de988cf', {boundingbox: [-3, 7, 5, -3], axis: true, showcopyright: false, shownavigation: false});
@@ -2101,7 +2107,7 @@ define([
      *   var s = board.create('slider',[[0,4],[3,4],[0,4,10]],{snapWidth:1});
      *   var r = board.create('riemannsum', [f, function(){return s.Value();}, 'upper', -2, 5], {fillOpacity:0.4});
      *   var g = board.create('functiongraph', [f, -2, 5]);
-     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + r.Value().toFixed(4); }]);
+     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + JXG.toFixed(r.Value(), 4); }]);
      * })();
      * </script><pre>
      *
@@ -2116,8 +2122,8 @@ define([
      *               );
      *   var f = board.create('functiongraph',[f, -2, 5]);
      *   var g = board.create('functiongraph',[g, -2, 5]);
-     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + r.Value().toFixed(4); }]);
-     * </pre><div class="jxgbox"id="f9a7ba38-b50f-4a32-a873-2f3bf9caee79" style="width: 300px; height: 300px;"></div>
+     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + JXG.toFixed(r.Value(), 4); }]);
+     * </pre><div class="jxgbox" id="f9a7ba38-b50f-4a32-a873-2f3bf9caee79" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function(){
      *   var board = JXG.JSXGraph.initBoard('f9a7ba38-b50f-4a32-a873-2f3bf9caee79', {boundingbox: [-3, 7, 5, -3], axis: true, showcopyright: false, shownavigation: false});
@@ -2130,7 +2136,7 @@ define([
      *               );
      *   var f = board.create('functiongraph',[f, -2, 5]);
      *   var g = board.create('functiongraph',[g, -2, 5]);
-     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + r.Value().toFixed(4); }]);
+     *   var t = board.create('text',[-2,-2, function(){ return 'Sum=' + JXG.toFixed(r.Value(), 4); }]);
      * })();
      * </script><pre>
      */
@@ -2197,7 +2203,7 @@ define([
      * p2 = board.create('midpoint',[s1]),
      * curve = board.create('tracecurve', [g1, p2]);
      *
-     * </pre><div class="jxgbox"id="5749fb7d-04fc-44d2-973e-45c1951e29ad" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="5749fb7d-04fc-44d2-973e-45c1951e29ad" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var tc1_board = JXG.JSXGraph.initBoard('5749fb7d-04fc-44d2-973e-45c1951e29ad', {boundingbox: [-4, 4, 4, -4], axis: false, showcopyright: false, shownavigation: false});
      *   var c1 = tc1_board.create('circle',[[0, 0], [2, 0]]),
@@ -2338,7 +2344,7 @@ define([
      * // Create step function.
      var curve = board.create('stepfunction', [[0,1,2,3,4,5], [1,3,0,2,2,1]]);
 
-     * </pre><div class="jxgbox"id="32342ec9-ad17-4339-8a97-ff23dc34f51a" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="32342ec9-ad17-4339-8a97-ff23dc34f51a" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var sf1_board = JXG.JSXGraph.initBoard('32342ec9-ad17-4339-8a97-ff23dc34f51a', {boundingbox: [-1, 5, 6, -2], axis: true, showcopyright: false, shownavigation: false});
      *   var curve = sf1_board.create('stepfunction', [[0,1,2,3,4,5], [1,3,0,2,2,1]]);
