@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -171,7 +171,33 @@ define([
         this.symbolic = {};
 
         /**
-         * Stores the rendering node for the element.
+         * Stores the SVG (or VML) rendering node for the element. This enables low-level
+         * access to SVG nodes. The properties of such an SVG node can then be changed
+         * by calling setAttribute(). Note that there are a few elements which consist
+         * of more than one SVG nodes:
+         * <ul>
+         * <li> Elements with arrow tail or head: rendNodeTriangleStart, rendNodeTriangleEnd
+         * <li> SVG (or VML) texts: rendNodeText
+         * <li> Button: rendNodeForm, rendNodeButton, rendNodeTag
+         * <li> Checkbox: rendNodeForm, rendNodeCheckbox, rendNodeLabel, rendNodeTag
+         * <li> Input: rendNodeForm, rendNodeInput, rendNodeLabel, rendNodeTag
+         * </ul>
+         *
+         * Here is are two examples: The first example shows how to access the SVG node,
+         * the second example demonstrates how to change SVG attributes.
+         * @example
+         *     var p1 = board.create('point', [0, 0]);
+         *     console.log(p1.rendNode);
+         *     // returns the full SVG node details of the point p1, something like:
+         *     // &lt;ellipse id='box_jxgBoard1P6' stroke='#ff0000' stroke-opacity='1' stroke-width='2px'
+         *     //   fill='#ff0000' fill-opacity='1' cx='250' cy='250' rx='4' ry='4'
+         *     //   style='position: absolute;'&gt;
+         *     // &lt;/ellipse&gt;
+         *
+         * @example
+         *     var s = board.create('segment', [p1, p2], {strokeWidth: 60});
+         *     s.rendNode.setAttribute('stroke-linecap', 'round');
+         *
          * @type Object
          */
         this.rendNode = null;
@@ -196,6 +222,13 @@ define([
          */
         this.subs = {};
 
+        /**
+         * Inherits contains the subelements, which may have an attribute
+         * (in partuclar the attribute "visible") having value 'inherit'.
+         * @type Object
+         */
+        this.inherits = [];
+
         /**
          * The position of this element inside the {@link JXG.Board#objectsList}.
          * @type {Number}
@@ -265,6 +298,21 @@ define([
          */
         this.visProp = {};
 
+        /**
+         * An associative array containing visual properties which are calculated from
+         * the attribute values (i.e. visProp) and from other constraints.
+         * An example: if an intersection point does not have real coordinates,
+         * visPropCalc.visible is set to false.
+         * Additionally, the user can control visibility with the attribute "visible",
+         * even by supplying a functions as value.
+         *
+         * @type Object
+         * @default empty object
+         */
+        this.visPropCalc = {
+            visible: false
+        };
+
         EventEmitter.eventify(this);
 
         /**
@@ -347,7 +395,7 @@ define([
 
             this.visProp.draft = attr.draft && attr.draft.draft;
             this.visProp.gradientangle = '270';
-            this.visProp.gradientsecondopacity = this.visProp.fillopacity;
+            this.visProp.gradientsecondopacity = Type.evaluate(this.visProp.fillopacity);
             this.visProp.gradientpositionx = 0.5;
             this.visProp.gradientpositiony = 0.5;
         }
@@ -429,7 +477,7 @@ define([
          *           return a * (x - ax) * (x - ax) + ay;
          *      }, {fixed: false});
          * f.addParents([A, B]);
-         * </pre><div class="jxgbox"id="7c91d4d2-986c-4378-8135-24505027f251" style="width: 400px; height: 400px;"></div>
+         * </pre><div class="jxgbox" id="7c91d4d2-986c-4378-8135-24505027f251" style="width: 400px; height: 400px;"></div>
          * <script type="text/javascript">
          * (function() {
          *   var board = JXG.JSXGraph.initBoard('7c91d4d2-986c-4378-8135-24505027f251', {boundingbox: [-1, 9, 9, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -459,6 +507,9 @@ define([
 
             len = par.length;
             for (i = 0; i < len; ++i) {
+                if (!Type.exists(par[i])) {
+                    continue;
+                }
                 if (Type.isId(this.board, par[i])) {
                     this.parents.push(par[i]);
                 } else if (Type.exists(par[i].id)) {
@@ -580,7 +631,7 @@ define([
          * @returns {boolean}
          */
         draggable: function () {
-            return this.isDraggable && !this.visProp.fixed &&
+            return this.isDraggable && !Type.evaluate(this.visProp.fixed) &&
                 /*!this.visProp.frozen &&*/ this.type !== Const.OBJECT_TYPE_GLIDER;
         },
 
@@ -596,7 +647,7 @@ define([
             var parents = [],
                 el, i, len, t;
 
-            if (!JXG.exists(this.parents)) {
+            if (!Type.exists(this.parents)) {
                 return this;
             }
 
@@ -764,9 +815,10 @@ define([
         /**
          * General update method. Should be overwritten by the element itself.
          * Can be used sometimes to commit changes to the object.
+         * @return {JXG.GeometryElement} Reference to the element
          */
         update: function () {
-            if (this.visProp.trace) {
+            if (Type.evaluate(this.visProp.trace)) {
                 this.cloneToBackground();
             }
             return this;
@@ -774,22 +826,92 @@ define([
 
         /**
          * Provide updateRenderer method.
+         * @return {JXG.GeometryElement} Reference to the element
          * @private
          */
         updateRenderer: function () {
             return this;
         },
 
+        /**
+         * Run through the full update chain of an element.
+         * @param  {Boolean} visible Set visibility in case the elements attribute value is 'inherit'. null is allowed.
+         * @return {JXG.GeometryElement} Reference to the element
+         * @private
+         */
+        fullUpdate: function(visible) {
+            return this.prepareUpdate()
+                .update()
+                .updateVisibility(visible)
+                .updateRenderer();
+        },
+
+        /**
+         * Show the element or hide it. If hidden, it will still exist but not be
+         * visible on the board.
+         * @param  {Boolean} val true: show the element, false: hide the element
+         * @return {JXG.GeometryElement} Reference to the element
+         * @private
+         */
+        setDisplayRendNode: function(val) {
+            var i, len, s, len_s, obj;
+
+            if (val === undefined) {
+                val = this.visPropCalc.visible;
+            }
+
+            if (val === this.visPropOld.visible) {
+                return this;
+            }
+
+            // Set display of the element itself
+            this.board.renderer.display(this, val);
+
+            // Set the visibility of elements which inherit the attribute 'visible'
+            len = this.inherits.length;
+            for (s = 0; s < len; s++) {
+                obj = this.inherits[s];
+                if (Type.isArray(obj)) {
+                    len_s = obj.length;
+                    for (i = 0; i < len_s; i++) {
+                        if (Type.exists(obj[i]) && Type.exists(obj[i].rendNode) &&
+                            Type.evaluate(obj[i].visProp.visible) === 'inherit') {
+                            obj[i].setDisplayRendNode(val);
+                        }
+                    }
+                } else {
+                    if (Type.exists(obj) && Type.exists(obj.rendNode) &&
+                        Type.evaluate(obj.visProp.visible) === 'inherit') {
+                            obj.setDisplayRendNode(val);
+                    }
+                }
+            }
+
+            // Set the visibility of the label if it inherits the attribute 'visible'
+            if (this.hasLabel && Type.exists(this.label) && Type.exists(this.label.rendNode)) {
+                if (Type.evaluate(this.label.visProp.visible) === 'inherit') {
+                    this.label.setDisplayRendNode(val);
+                }
+            }
+
+            return this;
+        },
+
         /**
          * Hide the element. It will still exist but not visible on the board.
+         * @return {JXG.GeometryElement} Reference to the element
+         * @deprecated
+         * @private
          */
         hideElement: function () {
-            this.visProp.visible = false;
-            this.board.renderer.hide(this);
+            JXG.deprecated('Element.hideElement()', 'Element.setDisplayRendNode()');
+
+            this.visPropCalc.visible = false;
+            this.board.renderer.display(this, false);
 
             if (Type.exists(this.label) && this.hasLabel) {
                 this.label.hiddenByParent = true;
-                if (this.label.visProp.visible) {
+                if (this.label.visPropCalc.visible) {
                     this.label.hideElement();
                 }
             }
@@ -798,20 +920,96 @@ define([
 
         /**
          * Make the element visible.
+         * @return {JXG.GeometryElement} Reference to the element
+         * @deprecated
+         * @private
          */
         showElement: function () {
-            this.visProp.visible = true;
-            this.board.renderer.show(this);
+            JXG.deprecated('Element.showElement()', 'Element.setDisplayRendNode()');
+
+            this.visPropCalc.visible = true;
+            this.board.renderer.display(this, true);
 
             if (Type.exists(this.label) && this.hasLabel && this.label.hiddenByParent) {
                 this.label.hiddenByParent = false;
-                if (!this.label.visProp.visible) {
+                if (!this.label.visPropCalc.visible) {
                     this.label.showElement().updateRenderer();
                 }
             }
             return this;
         },
 
+        /**
+         * Set the visibility of an element. The visibility is influenced by
+         * (listed in ascending priority):
+         * <ol>
+         * <li> The value of the element's attribute 'visible'
+         * <li> The visibility of a parent element. (Example: label)
+         * This overrules the value of the element's attribute value only if
+         * this attribute value of the element is 'inherit'.
+         * <li> being inside of the canvas
+         * </ol>
+         * <p>
+         * This method is called three times for most elements:
+         * <ol>
+         * <li> between {@link JXG.GeometryElement#update}
+         * and {@link JXG.GeometryElement#updateRenderer}. In case the value is 'inherit', nothing is done.
+         * <li> Recursively, called by itself for child elements. Here, 'inherit' is overruled by the parent's value.
+         * <li> In {@link JXG.GeometryElement#updateRenderer}, if the element is outside of the canvas.
+         * </ol>
+         *
+         * @param  {Boolean} parent_val Visibility of the parent element.
+         * @return {JXG.GeometryElement} Reference to the element.
+         * @private
+         */
+        updateVisibility: function(parent_val) {
+            var i, len, s, len_s, obj, val;
+
+            if (this.needsUpdate) {
+                // Handle the element
+                if (parent_val !== undefined) {
+                    this.visPropCalc.visible = parent_val;
+                } else {
+                    val = Type.evaluate(this.visProp.visible);
+
+                    // infobox uses hiddenByParent
+                    if (Type.exists(this.hiddenByParent) && this.hiddenByParent) {
+                        val = false;
+                    }
+                    if (val !== 'inherit') {
+                        this.visPropCalc.visible = val;
+                    }
+                }
+
+                // Handle elements which inherit the visibility
+                len = this.inherits.length;
+                for (s = 0; s < len; s++) {
+                    obj = this.inherits[s];
+                    if (Type.isArray(obj)) {
+                        len_s = obj.length;
+                        for (i = 0; i < len_s; i++) {
+                            if (Type.exists(obj[i]) /*&& Type.exists(obj[i].rendNode)*/ &&
+                                Type.evaluate(obj[i].visProp.visible) === 'inherit') {
+                                obj[i].prepareUpdate().updateVisibility(this.visPropCalc.visible);
+                            }
+                        }
+                    } else {
+                        if (Type.exists(obj) /*&& Type.exists(obj.rendNode)*/ &&
+                            Type.evaluate(obj.visProp.visible) === 'inherit') {
+                            obj.prepareUpdate().updateVisibility(this.visPropCalc.visible);
+                        }
+                    }
+                }
+
+                // Handle the label if it inherits the visibility
+                if (Type.exists(this.label)  && Type.exists(this.label.visProp) &&
+                    Type.evaluate(this.label.visProp.visible)) {
+                    this.label.prepareUpdate().updateVisibility(this.visPropCalc.visible);
+                }
+            }
+            return this;
+        },
+
         /**
          * Sets the value of property <tt>property</tt> to <tt>value</tt>.
          * @param {String} property The property's name.
@@ -823,8 +1021,12 @@ define([
 
             // Search for entries in visProp with "color" as part of the property name
             // and containing a RGBA string
-            if (this.visProp.hasOwnProperty(property) && property.indexOf('color') >= 0 &&
-                    Type.isString(value) && value.length === 9 && value.charAt(0) === '#') {
+            if (this.visProp.hasOwnProperty(property) &&
+                  property.indexOf('color') >= 0 &&
+                  Type.isString(value) &&
+                  value.length === 9 &&
+                  value.charAt(0) === '#') {
+
                 value = Color.rgba2rgbo(value);
                 this.visProp[property] = value[0];
                 // Previously: *=. But then, we can only decrease opacity.
@@ -920,7 +1122,7 @@ define([
          * });
          */
         setAttribute: function (attributes) {
-            var i, key, value, arg, opacity, pair, oldvalue,
+            var i, j, le, key, value, arg, opacity, pair, oldvalue,
                 properties = {};
 
             // normalize the user input
@@ -948,6 +1150,28 @@ define([
                     value = properties[i];
                     oldvalue = this.visProp[key];
 
+                    // This handles the subobjects, if the key:value pairs are contained in an object.
+                    // Example
+                    // ticks.setAttribute({
+                    //      strokeColor: 'blue',
+                    //      label: {
+                    //          visible: false
+                    //      }
+                    // })
+                    // Now, only the supplied label attributes are overwritten.
+                    // Otherwise, the the value of label would be {visible:false} only.
+                    if (Type.isObject(value) && Type.exists(this.visProp[key])) {
+                        this.visProp[key] = Type.merge(this.visProp[key], value);
+
+                        if (this.type === Const.OBJECT_TYPE_TICKS && Type.exists(this.labels)) {
+                            le = this.labels.length;
+                            for (j = 0; j < le; j++) {
+                                this.labels[j].setAttribute(value);
+                            }
+                        }
+                        continue;
+                    }
+
                     switch (key) {
                     case 'name':
                         oldvalue = this.name;
@@ -970,12 +1194,14 @@ define([
                         }
                         if (Type.exists(this.label) && this.hasLabel) {
                             this.label.visProp.strokecolor = value;
-                            this.board.renderer.setObjectStrokeColor(this.label, value, opacity);
+                            this.board.renderer.setObjectStrokeColor(this.label,
+                                value, opacity);
                         }
                         if (this.elementClass === Const.OBJECT_CLASS_TEXT) {
                             this.visProp.strokecolor = value;
                             this.visProp.strokeopacity = opacity;
-                            this.board.renderer.setObjectStrokeColor(this, this.visProp.strokecolor, this.visProp.strokeopacity);
+                            this.board.renderer.setObjectStrokeColor(this,
+                                value, opacity);
                         }
                         break;
                     case 'infoboxtext':
@@ -986,13 +1212,15 @@ define([
                         }
                         break;
                     case 'visible':
-                        if (value === 'false' || value === false) {
+                        if (value === 'false') {
                             this.visProp.visible = false;
-                            this.hideElement();
-                        } else if (value === 'true' || value === true) {
+                        } else if (value === 'true') {
                             this.visProp.visible = true;
-                            this.showElement();
+                        } else {
+                            this.visProp.visible = value;
                         }
+
+                        this.setDisplayRendNode(Type.evaluate(this.visProp.visible));
                         break;
                     case 'face':
                         if (Type.isPoint(this)) {
@@ -1024,21 +1252,15 @@ define([
                         break;
                     case 'withlabel':
                         this.visProp.withlabel = value;
-                        if (!value) {
+                        if (!Type.evaluate(value)) {
                             if (this.label && this.hasLabel) {
                                 this.label.hideElement();
                             }
                         } else {
-                            if (this.label) {
-                                if (this.visProp.visible) {
-                                    this.label.showElement();
-                                }
-                            } else {
+                            if (!this.label) {
                                 this.createLabel();
-                                if (!this.visProp.visible) {
-                                    this.label.hideElement();
-                                }
                             }
+                            this.label.setDisplayRendNode(Type.evaluate(this.visProp.visible));
                         }
                         this.hasLabel = value;
                         break;
@@ -1048,8 +1270,9 @@ define([
                         }
                         break;
                     case 'rotate':
-                        if ((this.elementClass === Const.OBJECT_CLASS_TEXT && this.visProp.display === 'internal') ||
-                                this.type === Const.OBJECT_TYPE_IMAGE) {
+                        if ((this.elementClass === Const.OBJECT_CLASS_TEXT &&
+                             Type.evaluate(this.visProp.display) === 'internal') ||
+                            this.type === Const.OBJECT_TYPE_IMAGE) {
                             this.addRotation(value);
                         }
                         break;
@@ -1070,14 +1293,23 @@ define([
                         break;
                     case 'disabled':
                         // button, checkbox, input. Is not available on initial call.
-                        if (JXG.exists(this.rendNodeTag)) {
+                        if (Type.exists(this.rendNodeTag)) {
                             this.rendNodeTag.disabled = !!value;
                         }
                         break;
+                    case 'maxlength':
+                        // input. Is not available on initial call.
+                        if (Type.exists(this.rendNodeTag)) {
+                            this.rendNodeTag.maxlength = !!value;
+                        }
+                        break;
                     default:
-                        if (Type.exists(this.visProp[key]) && (!JXG.Validator[key] || (JXG.Validator[key] &&
-                                JXG.Validator[key](value)) || (JXG.Validator[key] &&
-                                Type.isFunction(value) && JXG.Validator[key](value())))) {
+                        if (Type.exists(this.visProp[key]) &&
+                            (!JXG.Validator[key] ||
+                                (JXG.Validator[key] && JXG.Validator[key](value)) ||
+                                (JXG.Validator[key] && Type.isFunction(value) && JXG.Validator[key](value()))
+                            )
+                        ) {
                             value = value.toLowerCase && value.toLowerCase() === 'false' ? false : value;
                             this._set(key, value);
                         }
@@ -1089,7 +1321,7 @@ define([
 
             this.triggerEventHandlers(['attribute'], [properties, this]);
 
-            if (!this.visProp.needsregularupdate) {
+            if (!Type.evaluate(this.visProp.needsregularupdate)) {
                 this.board.fullUpdate();
             } else {
                 this.board.update(this);
@@ -1194,13 +1426,20 @@ define([
 
         /**
          * Determines whether the element has arrows at start or end of the arc.
+         * If it is set to be a "typical" vector, ie lastArrow == true,
+         * then the element.type is set to VECTOR.
          * @param {Boolean} firstArrow True if there is an arrow at the start of the arc, false otherwise.
          * @param {Boolean} lastArrow True if there is an arrow at the end of the arc, false otherwise.
          */
         setArrow: function (firstArrow, lastArrow) {
             this.visProp.firstarrow = firstArrow;
             this.visProp.lastarrow = lastArrow;
-            this.prepareUpdate().update();
+            if (lastArrow) {
+                this.type = Const.OBJECT_TYPE_VECTOR;
+                this.elType = 'arrow';
+            }
+
+            this.prepareUpdate().update().updateVisibility().updateRenderer();
             return this;
         },
 
@@ -1210,12 +1449,13 @@ define([
          * @private
          */
         createGradient: function () {
-            if (this.visProp.gradient === 'linear' || this.visProp.gradient === 'radial') {
+            var ev_g = Type.evaluate(this.visProp.gradient);
+            if (ev_g === 'linear' || ev_g === 'radial') {
                 this.board.renderer.setGradient(this);
             }
         },
 
-        /**
+         /**
          * Creates a label element for this geometry element.
          * @see #addLabelToElement
          */
@@ -1230,7 +1470,6 @@ define([
                 attr =  Type.deepCopy(this.visProp.label, null);
                 attr.id = this.id + 'Label';
                 attr.isLabel = true;
-                attr.visible = this.visProp.visible;
                 attr.anchor = this;
                 attr.priv = this.visProp.priv;
 
@@ -1242,14 +1481,14 @@ define([
                         return that.name;
                     }], attr);
                     this.label.needsUpdate = true;
+                    this.label.dump = false;
                     this.label.update();
 
-                    this.label.dump = false;
-
-                    if (!this.visProp.visible) {
-                        this.label.hiddenByParent = true;
-                        this.label.visProp.visible = false;
-                    }
+                    // if (!Type.evaluate(this.visProp.visible)) {
+                    //     this.label.hiddenByParent = true;
+                    //     this.label.visPropCalc.visible = false;
+                    // }
+                    // this.label.fullUpdate();
                     this.hasLabel = true;
                 }
             } else {
@@ -1279,7 +1518,8 @@ define([
             //    through dehighlightAll.
 
             // highlight only if not highlighted
-            if (this.visProp.highlight && (!this.highlighted || force)) {
+            if (Type.evaluate(this.visProp.highlight)
+                    && (!this.highlighted || force)) {
                 this.highlighted = true;
                 this.board.highlightedObjects[this.id] = this;
                 this.board.renderer.highlight(this);
@@ -1382,7 +1622,8 @@ define([
             var tOffInv, tOff, tS, tSInv, tRot,
                 that = this;
 
-            if (((this.elementClass === Const.OBJECT_CLASS_TEXT && this.visProp.display === 'internal') ||
+            if (((this.elementClass === Const.OBJECT_CLASS_TEXT &&
+                    Type.evaluate(this.visProp.display) === 'internal') ||
                     this.type === Const.OBJECT_TYPE_IMAGE) && angle !== 0) {
 
                 tOffInv = this.board.create('transform', [
@@ -1624,35 +1865,14 @@ define([
                 //i, len, g, el, p,
                 boardBB,
                 needsSnapToGrid = false,
-                sX = this.visProp.snapsizex,
-                sY = this.visProp.snapsizey;
+                sX = Type.evaluate(this.visProp.snapsizex),
+                sY = Type.evaluate(this.visProp.snapsizey);
 
-            if (!JXG.exists(this.coords)) {
+            if (!Type.exists(this.coords)) {
                 return this;
             }
 
-            needsSnapToGrid = this.visProp.snaptogrid || force === true;
-
-            // Test if in any of the groups this element is member of
-            // there is an element with snaptogrid == true.
-            /*
-            if (!needsSnapToGrid && Type.exists(this.groups)) {
-                len = this.groups.length;
-                for (i = 0; i < len; ++i) {
-                    g = this.board.groups[this.groups[i]];
-                    for (el in g.objects) {
-                        if (g.objects.hasOwnProperty(el)) {
-                            if (g.objects[el].point.visProp.snaptogrid) {
-                                needsSnapToGrid = true;
-                                // Leave both loops immediately
-                                i = len;
-                                break;
-                            }
-                        }
-                    }
-                }
-            }
-            */
+            needsSnapToGrid = Type.evaluate(this.visProp.snaptogrid) || force === true;
 
             if (needsSnapToGrid) {
                 x = this.coords.usrCoords[1];
@@ -1660,12 +1880,12 @@ define([
 
                 if (sX <= 0 && this.board.defaultAxes && this.board.defaultAxes.x.defaultTicks) {
                     ticks = this.board.defaultAxes.x.defaultTicks;
-                    sX = ticks.ticksDelta * (ticks.visProp.minorticks + 1);
+                    sX = ticks.ticksDelta * (Type.evaluate(ticks.visProp.minorticks) + 1);
                 }
 
                 if (sY <= 0 && this.board.defaultAxes && this.board.defaultAxes.y.defaultTicks) {
                     ticks = this.board.defaultAxes.y.defaultTicks;
-                    sY = ticks.ticksDelta * (ticks.visProp.minorticks + 1);
+                    sY = ticks.ticksDelta * (Type.evaluate(ticks.visProp.minorticks) + 1);
                 }
 
                 // if no valid snap sizes are available, don't change the coords.
@@ -1841,7 +2061,7 @@ define([
 
         /**
          * @event
-         * @description Notify everytime an attribute is changed.
+         * @description Notify every time an attribute is changed.
          * @name JXG.GeometryElement#attribute
          * @param {Object} o A list of changed attributes and their new value.
          * @param {Object} el Reference to the element
