@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -84,7 +84,7 @@ define([
         this.constructor(board, attributes, Const.OBJECT_TYPE_TEXT, Const.OBJECT_CLASS_TEXT);
 
         this.element = this.board.select(attributes.anchor);
-        this.coordsConstructor(coords, this.visProp.islabel);
+        this.coordsConstructor(coords, Type.evaluate(this.visProp.islabel));
 
         this.content = '';
         this.plaintext = '';
@@ -92,6 +92,7 @@ define([
         this.orgText = '';
 
         this.needsSizeUpdate = false;
+        // Only used by infobox anymore
         this.hiddenByParent = false;
 
         this.size = [1.0, 1.0];
@@ -132,7 +133,7 @@ define([
          * @returns {Boolean}
          */
         hasPoint: function (x, y) {
-            var lft, rt, top, bot,
+            var lft, rt, top, bot, ax, ay,
                 r = this.board.options.precision.hasPoint;
 
             if (this.transformations.length > 0) {
@@ -143,25 +144,27 @@ define([
                 y = lft[2];
             }
 
-            if (this.visProp.anchorx === 'right') {
+            ax = Type.evaluate(this.visProp.anchorx);
+            if (ax === 'right') {
                 lft = this.coords.scrCoords[1] - this.size[0];
-            } else if (this.visProp.anchorx === 'middle') {
+            } else if (ax === 'middle') {
                 lft = this.coords.scrCoords[1] - 0.5 * this.size[0];
             } else {
                 lft = this.coords.scrCoords[1];
             }
             rt = lft + this.size[0];
 
-            if (this.visProp.anchory === 'top') {
+            ay = Type.evaluate(this.visProp.anchory);
+            if (ay === 'top') {
                 bot = this.coords.scrCoords[2] + this.size[1];
-            } else if (this.visProp.anchory === 'middle') {
+            } else if (ay === 'middle') {
                 bot = this.coords.scrCoords[2] + 0.5 * this.size[1];
             } else {
                 bot = this.coords.scrCoords[2];
             }
             top = bot - this.size[1];
 
-            if (this.visProp.dragarea === 'all') {
+            if (Type.evaluate(this.visProp.dragarea) === 'all') {
                 return x >= lft - r && x < rt + r && y >= top - r  && y <= bot + r;
             }
 
@@ -171,35 +174,38 @@ define([
         },
 
         /**
-         * This sets the updateText function of this element that depending on the type of text content passed.
+         * This sets the updateText function of this element depending on the type of text content passed.
          * Used by {@link JXG.Text#_setText} and {@link JXG.Text} constructor.
          * @param {String|Function|Number} text
          * @private
          */
         _setUpdateText: function (text) {
-            var updateText;
+            var updateText, resolvedText,
+                ev_p = Type.evaluate(this.visProp.parse),
+                ev_um = Type.evaluate(this.visProp.usemathjax);
 
             this.orgText = text;
             if (Type.isFunction(text)) {
                 this.updateText = function () {
-                    if (this.visProp.parse && !this.visProp.usemathjax) {
-                        this.plaintext = this.replaceSub(this.replaceSup(this.convertGeonext2CSS(text())));
+                    resolvedText = text().toString();
+                    if (ev_p && !ev_um) {
+                        this.plaintext = this.replaceSub(this.replaceSup(this.convertGeonext2CSS(resolvedText)));
                     } else {
-                        this.plaintext = text();
+                        this.plaintext = resolvedText;
                     }
                 };
-            } else if (Type.isString(text) && !this.visProp.parse) {
+            } else if (Type.isString(text) && !ev_p) {
                 this.updateText = function () {
                     this.plaintext = text;
                 };
             } else {
                 if (Type.isNumber(text)) {
-                    this.content = text.toFixed(this.visProp.digits);
+                    this.content = Type.toFixed(text, Type.evaluate(this.visProp.digits));
                 } else {
-                    if (this.visProp.useasciimathml) {
+                    if (Type.evaluate(this.visProp.useasciimathml)) {
                         // Convert via ASCIIMathML
                         this.content = "'`" + text + "`'";
-                    } else if (this.visProp.usemathjax) {
+                    } else if (ev_um) {
                         this.content = "'" + text + "'";
                     } else {
                         // Converts GEONExT syntax into JavaScript string
@@ -227,7 +233,7 @@ define([
             // First evaluation of the string.
             // We need this for display='internal' and Canvas
             this.updateText();
-            this.prepareUpdate().update().updateRenderer();
+            this.fullUpdate();
 
             // We do not call updateSize for the infobox to speed up rendering
             if (!this.board.infobox || this.id !== this.board.infobox.id) {
@@ -281,24 +287,26 @@ define([
          * for aligning text.
          */
         updateSize: function () {
-            var tmp, s, that, node;
+            var tmp, s, that, node,
+                ev_d = Type.evaluate(this.visProp.display);
 
             if (!Env.isBrowser || this.board.renderer.type === 'no') {
                 return this;
             }
-
             node = this.rendNode;
 
             /**
              * offsetWidth and offsetHeight seem to be supported for internal vml elements by IE10+ in IE8 mode.
              */
-            if (this.visProp.display === 'html' || this.board.renderer.type === 'vml') {
-                if (JXG.exists(node.offsetWidth)) {
+            if (ev_d === 'html' || this.board.renderer.type === 'vml') {
+                if (Type.exists(node.offsetWidth)) {
                     s = [node.offsetWidth, node.offsetHeight];
                     if (s[0] === 0 && s[1] === 0) { // Some browsers need some time to set offsetWidth and offsetHeight
                         that = this;
                         window.setTimeout(function () {
                             that.size = [node.offsetWidth, node.offsetHeight];
+                            that.needsUpdate = true;
+                            that.updateRenderer();
                         }, 0);
                     } else {
                         this.size = s;
@@ -306,7 +314,7 @@ define([
                 } else {
                     this.size = this.crudeSizeEstimate();
                 }
-            } else if (this.visProp.display === 'internal') {
+            } else if (ev_d === 'internal') {
                 if (this.board.renderer.type === 'svg') {
                     try {
                         tmp = node.getBBox();
@@ -325,7 +333,8 @@ define([
          * @returns {Array}
          */
         crudeSizeEstimate: function () {
-            return [parseFloat(this.visProp.fontsize) * this.plaintext.length * 0.45, parseFloat(this.visProp.fontsize) * 0.9];
+            var ev_fs = parseFloat(Type.evaluate(this.visProp.fontsize));
+            return [ev_fs * this.plaintext.length * 0.45, ev_fs * 0.9];
         },
 
         /**
@@ -430,7 +439,7 @@ define([
                 x = x[0];
             }
 
-            if (this.visProp.islabel && Type.exists(this.element)) {
+            if (Type.evaluate(this.visProp.islabel) && Type.exists(this.element)) {
                 coordsAnchor = this.element.getLabelAnchor();
                 dx = (x - coordsAnchor.usrCoords[1]) * this.board.unitX;
                 dy = -(y - coordsAnchor.usrCoords[2]) * this.board.unitY;
@@ -451,7 +460,7 @@ define([
 
             // this should be a local update, otherwise there might be problems
             // with the tick update routine resulting in orphaned tick labels
-            this.prepareUpdate().update().updateRenderer();
+            this.fullUpdate();
 
             return this;
         },
@@ -469,7 +478,7 @@ define([
             this.updateCoords(fromParent);
             this.updateText();
 
-            if (this.visProp.display === 'internal') {
+            if (Type.evaluate(this.visProp.display) === 'internal') {
                 this.plaintext = this.utf8_decode(this.plaintext);
             }
 
@@ -577,7 +586,7 @@ define([
                         // output of a value tag
                         if (Type.isNumber((Type.bind(this.board.jc.snippet(res, true, '', false), this))())) {
                             // may also be a string
-                            plaintext += '+(' + res + ').toFixed(' + (this.visProp.digits) + ')';
+                            plaintext += '+(' + res + ').toFixed(' + (Type.evaluate(this.visProp.digits)) + ')';
                         } else {
                             plaintext += '+(' + res + ')';
                         }
@@ -669,7 +678,7 @@ define([
         bounds: function () {
             var c = this.coords.usrCoords;
 
-            if (this.visProp.islabel || this.board.unitY === 0 || this.board.unitX === 0) {
+            if (Type.evaluate(this.visProp.islabel) || this.board.unitY === 0 || this.board.unitX === 0) {
                 return [0, 0, 0, 0];
             } else {
                 return [c[1], c[2] + this.size[1] / this.board.unitY, c[1] + this.size[0] / this.board.unitX, c[2]];
@@ -708,7 +717,7 @@ define([
      * @example
      * // Create a fixed text at position [0,1].
      *   var t1 = board.create('text',[0,1,"Hello World"]);
-     * </pre><div class="jxgbox"id="896013aa-f24e-4e83-ad50-7bc7df23f6b7" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="896013aa-f24e-4e83-ad50-7bc7df23f6b7" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var t1_board = JXG.JSXGraph.initBoard('896013aa-f24e-4e83-ad50-7bc7df23f6b7', {boundingbox: [-3, 6, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var t1 = t1_board.create('text',[0,1,"Hello World"]);
@@ -718,21 +727,21 @@ define([
      *   var s = board.create('slider',[[0,4],[3,4],[-2,0,2]]);
      *   var graph = board.create('text',
      *                        [function(x){ return s.Value();}, 1,
-     *                         function(){return "The value of s is"+s.Value().toFixed(2);}
+     *                         function(){return "The value of s is"+JXG.toFixed(s.Value(), 2);}
      *                        ]
      *                     );
-     * </pre><div class="jxgbox"id="5441da79-a48d-48e8-9e53-75594c384a1c" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="5441da79-a48d-48e8-9e53-75594c384a1c" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var t2_board = JXG.JSXGraph.initBoard('5441da79-a48d-48e8-9e53-75594c384a1c', {boundingbox: [-3, 6, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *   var s = t2_board.create('slider',[[0,4],[3,4],[-2,0,2]]);
-     *   var t2 = t2_board.create('text',[function(x){ return s.Value();}, 1, function(){return "The value of s is "+s.Value().toFixed(2);}]);
+     *   var t2 = t2_board.create('text',[function(x){ return s.Value();}, 1, function(){return "The value of s is "+JXG.toFixed(s.Value(), 2);}]);
      * </script><pre>
      * @example
      * // Create a text bound to the point A
      * var p = board.create('point',[0, 1]),
      *     t = board.create('text',[0, -1,"Hello World"], {anchor: p});
      *
-     * </pre><div class="jxgbox"id="ff5a64b2-2b9a-11e5-8dd9-901b0e1b8723" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="ff5a64b2-2b9a-11e5-8dd9-901b0e1b8723" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *     (function() {
      *         var board = JXG.JSXGraph.initBoard('ff5a64b2-2b9a-11e5-8dd9-901b0e1b8723',
@@ -770,6 +779,19 @@ define([
 
     JXG.registerElement('text', JXG.createText);
 
+    /**
+     * @class Labels are text objects tied to other elements like points, lines and curves.
+     * Labels are handled internally by JSXGraph, only. There is NO constructor "board.create('label', ...)".
+     *
+     * @pseudo
+     * @description
+     * @name Label
+     * @augments JXG.Text
+     * @constructor
+     * @type JXG.Text
+     */
+    //  See element.js#createLabel
+
     /**
      * [[x,y], [w px, h px], [range]
      */
