@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -77,7 +77,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="114ef584-4a5e-4686-8392-c97501befb5b" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="114ef584-4a5e-4686-8392-c97501befb5b" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('114ef584-4a5e-4686-8392-c97501befb5b', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -154,11 +154,12 @@ define([
                 sgn = 1,
                 A = this.radiuspoint,
                 B = this.center,
-                C = this.anglepoint;
+                C = this.anglepoint,
+                ev_s = Type.evaluate(this.visProp.selection);
 
             phi = Geometry.rad(A, B, C);
-            if ((this.visProp.selection === 'minor' && phi > Math.PI) ||
-                    (this.visProp.selection === 'major' && phi < Math.PI)) {
+            if ((ev_s === 'minor' && phi > Math.PI) ||
+                    (ev_s === 'major' && phi < Math.PI)) {
                 sgn = -1;
             }
 
@@ -233,9 +234,11 @@ define([
             var dist, checkPoint,
                 has, angle, alpha, beta,
                 invMat, c,
-                prec = this.board.options.precision.hasPoint / this.board.unitX,
-                r = this.Radius();
+                prec,
+                r = this.Radius(),
+                ev_s = Type.evaluate(this.visProp.selection);
 
+            prec = this.board.options.precision.hasPoint / Math.min(this.board.unitX, this.board.unitY);
             checkPoint = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board);
 
             if (this.transformations.length > 0) {
@@ -258,8 +261,8 @@ define([
                 alpha = 0.0;
                 beta = Geometry.rad(this.radiuspoint, this.center, this.anglepoint);
 
-                if ((this.visProp.selection === 'minor' && beta > Math.PI) ||
-                        (this.visProp.selection === 'major' && beta < Math.PI)) {
+                if ((ev_s === 'minor' && beta > Math.PI) ||
+                        (ev_s === 'major' && beta < Math.PI)) {
                     alpha = beta;
                     beta = 2 * Math.PI;
                 }
@@ -285,15 +288,16 @@ define([
                 checkPoint = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board),
                 r = this.Radius(),
                 dist = this.center.coords.distance(Const.COORDS_BY_USER, checkPoint),
-                has = (dist < r);
+                has = (dist < r),
+                ev_s = Type.evaluate(this.visProp.selection);
 
             if (has) {
                 angle = Geometry.rad(this.radiuspoint, this.center, checkPoint.usrCoords.slice(1));
                 alpha = 0;
                 beta = Geometry.rad(this.radiuspoint, this.center, this.anglepoint);
 
-                if ((this.visProp.selection === 'minor' && beta > Math.PI) ||
-                        (this.visProp.selection === 'major' && beta < Math.PI)) {
+                if ((ev_s === 'minor' && beta > Math.PI) ||
+                        (ev_s === 'major' && beta < Math.PI)) {
                     alpha = beta;
                     beta = 2 * Math.PI;
                 }
@@ -319,15 +323,16 @@ define([
                 p2c = this.point2.coords.usrCoords,
                 pmc = this.center.coords.usrCoords,
                 bxminusax = p2c[1] - pmc[1],
-                byminusay = p2c[2] - pmc[2];
+                byminusay = p2c[2] - pmc[2],
+                ev_s = Type.evaluate(this.visProp.selection);
 
             // If this is uncommented, the angle label can not be dragged
             //if (Type.exists(this.label)) {
             //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
             //}
 
-            if ((this.visProp.selection === 'minor' && angle > Math.PI) ||
-                    (this.visProp.selection === 'major' && angle < Math.PI)) {
+            if ((ev_s === 'minor' && angle > Math.PI) ||
+                    (ev_s === 'major' && angle < Math.PI)) {
                 angle = -(2 * Math.PI - angle);
             }
 
@@ -383,7 +388,7 @@ define([
      * var p2 = board.create('point', [1.0, 0.5]);
      *
      * var a = board.create('semicircle', [p1, p2]);
-     * </pre><div class="jxgbox"id="5385d349-75d7-4078-b732-9ae808db1b0e" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="5385d349-75d7-4078-b732-9ae808db1b0e" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('5385d349-75d7-4078-b732-9ae808db1b0e', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -416,6 +421,7 @@ define([
         el.subs = {
             midpoint: mp
         };
+        el.inherits.push(mp);
 
         /**
          * The midpoint of the two defining points.
@@ -448,7 +454,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="87125fd4-823a-41c1-88ef-d1a1369504e3" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="87125fd4-823a-41c1-88ef-d1a1369504e3" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('87125fd4-823a-41c1-88ef-d1a1369504e3', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -484,6 +490,7 @@ define([
         el.subs = {
             center: mp
         };
+        el.inherits.push(mp);
 
         /**
          * The midpoint of the circumcircle of the three points defining the circumcircle arc.
@@ -517,7 +524,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('arc', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="64ba7ca2-8728-45f3-96e5-3c7a4414de2f" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="64ba7ca2-8728-45f3-96e5-3c7a4414de2f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('64ba7ca2-8728-45f3-96e5-3c7a4414de2f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -556,7 +563,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('minorarc', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="17a10d38-5629-40a4-b150-f41806edee9f" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="17a10d38-5629-40a4-b150-f41806edee9f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('17a10d38-5629-40a4-b150-f41806edee9f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
