@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -91,7 +91,7 @@ define([
      *      "$('p1').Y = $('p1').Y() - 0.5;"
      *  ], {});
      *
-     * </pre><div class="jxgbox"id="f19b1bce-dd00-4e35-be97-ff1817d11514" style="width: 500px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="f19b1bce-dd00-4e35-be97-ff1817d11514" style="width: 500px; height: 300px;"></div>
      * <script type="text/javascript">
      *  var t1_board = JXG.JSXGraph.initBoard('f19b1bce-dd00-4e35-be97-ff1817d11514', {boundingbox: [-3, 6, 5, -3], axis: true, showcopyright: false, shownavigation: false});
      *  var p = t1_board.create('point', [0, -1], {id: 'p1'});
@@ -119,9 +119,9 @@ define([
             //    "\nPossible parents are: [x, y, label, handler]");
         //}
 
-        par = [parents[0], parents[1], '<button type="button"></button>'];
+        par = [parents[0], parents[1], '<button type="button" style="width:100%;"></button>'];
 
-        t = JXG.createText(board, par, attr);
+        t = board.create('text', par, attr);
         t.type = Type.OBJECT_TYPE_BUTTON;
 
         t.rendNodeButton = t.rendNode.childNodes[0];
@@ -149,6 +149,10 @@ define([
 
         Env.addEvent(t.rendNodeButton, 'click', priv.ButtonClickEventHandler, t);
 
+        Env.addEvent(t.rendNodeButton, 'mousedown', function(evt) { evt.stopPropagation(); }, t);
+        Env.addEvent(t.rendNodeButton, 'touchstart', function(evt) { evt.stopPropagation(); }, t);
+        Env.addEvent(t.rendNodeButton, 'pointerdown', function(evt) { evt.stopPropagation(); }, t);
+
         return t;
     };
 
