@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -76,7 +76,7 @@ define([
      * var B = board.create('point', [-1,-4]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('ellipse',[A,B,C]);
-     * </pre><div class="jxgbox"id="a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('a4d7fb6f-8708-4e45-87f2-2379ae2bd2c0', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -91,6 +91,7 @@ define([
             // focus 1 and focus 2
             F = [],
             attr_foci = Type.copyAttributes(attributes, board.options, 'conic', 'foci'),
+            attr_center = Type.copyAttributes(attributes, board.options, 'conic', 'center'),
             attr_curve = Type.copyAttributes(attributes, board.options, 'conic');
 
         // The foci and the third point are either points or coordinate arrays.
@@ -160,7 +161,7 @@ define([
             function () {
                 return (F[0].Y() + F[1].Y()) * 0.5;
             }
-        ], attr_foci);
+        ], attr_center);
 
         curve = board.create('curve', [
             function (x) {
@@ -224,8 +225,15 @@ define([
             return F[0].Y() + Math.sin(beta + phi) * b;
         };
 
-        curve.midpoint = M;
+        curve.midpoint = curve.center = M;
         curve.type = Const.OBJECT_TYPE_CONIC;
+        curve.subs = {
+            center: curve.center
+        }
+        curve.inherits.push(curve.center, F[0], F[1]);
+        if (Type.isPoint(C)) {
+            curve.inherits.push(C);
+        }
 
         /**
          * Checks whether (x,y) is near the ellipse line or inside of the ellipse
@@ -238,7 +246,7 @@ define([
         curve.hasPoint =  function (x, y) {
             var ac, bc, r, p, dist;
 
-            if (this.visProp.hasinnerpoints) {
+            if (Type.evaluate(this.visProp.hasinnerpoints)) {
                 ac = F[0].coords;
                 bc = F[1].coords;
                 r = this.majorAxis();
@@ -286,7 +294,7 @@ define([
      * var B = board.create('point', [-1,-4]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('hyperbola',[A,B,C]);
-     * </pre><div class="jxgbox"id="cf99049d-a3fe-407f-b936-27d76550f8c4" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="cf99049d-a3fe-407f-b936-27d76550f8c4" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('cf99049d-a3fe-407f-b936-27d76550f8c4', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -300,6 +308,7 @@ define([
             // focus 1 and focus 2
             F = [],
             attr_foci = Type.copyAttributes(attributes, board.options, 'conic', 'foci'),
+            attr_center = Type.copyAttributes(attributes, board.options, 'conic', 'center'),
             attr_curve = Type.copyAttributes(attributes, board.options, 'conic');
 
         // The foci and the third point are either points or coordinate arrays.
@@ -369,7 +378,7 @@ define([
             function () {
                 return (F[0].Y() + F[1].Y()) * 0.5;
             }
-        ], attr_foci);
+        ], attr_center);
 
         curve = board.create('curve', [
             function (x) {
@@ -429,7 +438,14 @@ define([
             return F[0].Y() + Math.sin(beta + phi) * b;
         };
 
-        curve.midpoint = M;
+        curve.midpoint = curve.center = M;
+        curve.subs = {
+            center: curve.center
+        }
+        curve.inherits.push(curve.center, F[0], F[1]);
+        if (Type.isPoint(C)) {
+            curve.inherits.push(C);
+        }
         curve.type = Const.OBJECT_TYPE_CONIC;
 
         M.addChild(curve);
@@ -464,7 +480,7 @@ define([
      * var l = board.create('line', [A,B]);
      * var C = board.create('point', [1,1]);
      * var el = board.create('parabola',[C,l]);
-     * </pre><div class="jxgbox"id="524d1aae-217d-44d4-ac58-a19c7ab1de36" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="524d1aae-217d-44d4-ac58-a19c7ab1de36" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('524d1aae-217d-44d4-ac58-a19c7ab1de36', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [-1,4]);
@@ -481,6 +497,7 @@ define([
             // directrix
             l = parents[1],
             attr_foci = Type.copyAttributes(attributes, board.options, 'conic', 'foci'),
+            attr_center = Type.copyAttributes(attributes, board.options, 'conic', 'center'),
             attr_curve = Type.copyAttributes(attributes, board.options, 'conic');
 
         // focus 1 given by coordinates
@@ -520,7 +537,7 @@ define([
                 */
                 return Geometry.projectPointToLine(F1, l, board).usrCoords;
             }
-        ], attr_foci);
+        ], attr_center);
 
         /** @ignore */
         curve = board.create('curve', [
@@ -531,6 +548,12 @@ define([
                 return 0;
             }, parents[2], parents[3]], attr_curve);
 
+        curve.midpoint = curve.center = M;
+        curve.subs = {
+            center: curve.center
+        };
+        curve.inherits.push(curve.center);
+
         /** @ignore */
         polarForm = function (t, suspendUpdate) {
             var a, b, c, ab, px, py;
@@ -602,6 +625,7 @@ define([
 
         if (Type.isPoint(F1)) {
             F1.addChild(curve);
+            curve.inherits.push(F1);
         }
 
         l.addChild(curve);
@@ -630,7 +654,7 @@ define([
      *  var D = board.create('point', [0,0]);
      *  var E = board.create('point', [-1,5]);
      *  var conic = board.create('conic',[A,B,C,D,E]);
-     * </pre><div class="jxgbox"id="2d79bd6a-db9b-423c-9cba-2497f0b06320" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="2d79bd6a-db9b-423c-9cba-2497f0b06320" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      *   var glex1_board = JXG.JSXGraph.initBoard('2d79bd6a-db9b-423c-9cba-2497f0b06320', {boundingbox:[-6,6,6,-6], keepaspectratio:true, showcopyright: false, shownavigation: false});
      *   var A = glex1_board.create('point', [1,5]);
@@ -657,7 +681,8 @@ define([
             ],
             points = [],
             p = [],
-            attr_foci = Type.copyAttributes(attributes, board.options, 'conic', 'foci'),
+            attr_point = Type.copyAttributes(attributes, board.options, 'conic', 'point'),
+            attr_center = Type.copyAttributes(attributes, board.options, 'conic', 'center'),
             attr_curve = Type.copyAttributes(attributes, board.options, 'conic');
 
         if (parents.length === 5) {
@@ -672,7 +697,7 @@ define([
             for (i = 0; i < 5; i++) {
                 // point i given by coordinates
                 if (parents[i].length > 1) {
-                    points[i] = board.create('point', parents[i], attr_foci);
+                    points[i] = board.create('point', parents[i], attr_point);
                 // point i given by point
                 } else if (Type.isPoint(parents[i])) {
                     points[i] = board.select(parents[i]);
@@ -845,7 +870,7 @@ define([
                 v = Mat.matVecMult(rotationMatrix, [Math.sin(phi) / c, Math.cos(phi) / a, 1 / b]);
             }
 
-            if (JXG.exists(v)) {
+            if (Type.exists(v)) {
                 // Normalize
                 v[1] /= v[0];
                 v[2] /= v[0];
@@ -878,9 +903,15 @@ define([
                     m[0][1] * m[1][2] - m[1][1] * m[0][2]
                 ];
             }
-        ], attr_foci);
+        ], attr_center);
 
         curve.type = Const.OBJECT_TYPE_CONIC;
+        curve.center = curve.midpoint;
+        curve.subs = {
+            center: curve.center
+        };
+        curve.inherits.push(curve.center);
+        curve.inherits = curve.inherits.concat(points);
 
         if (givenByPoints) {
             for (i = 0; i < 5; i++) {
@@ -890,7 +921,7 @@ define([
             }
             curve.setParents(parents);
         }
-        curve.addChild(curve.midpoint);
+        curve.addChild(curve.center);
 
         return curve;
     };
