@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -81,7 +81,7 @@ define([
      *     p3 = board.create('point', [5.0, 3.0]),
      *
      *     a = board.create('sector', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="49f59123-f013-4681-bfd9-338b89893156" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="49f59123-f013-4681-bfd9-338b89893156" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('49f59123-f013-4681-bfd9-338b89893156', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -106,7 +106,7 @@ define([
      *  sec1 = board.create('sector', [li1, li2, [5.5, 0], [4, 3], 3]),
      *  sec2 = board.create('sector', [li1, li2, 1, -1, 4]);
      *
-     * </pre><div class="jxgbox"id="bb9e2809-9895-4ff1-adfa-c9c71d50aa53" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="bb9e2809-9895-4ff1-adfa-c9c71d50aa53" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('bb9e2809-9895-4ff1-adfa-c9c71d50aa53', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -327,7 +327,8 @@ define([
                     A = this.point2,
                     B = this.point1,
                     C = this.point3,
-                    phi, sgn = 1;
+                    phi, sgn = 1,
+                    vp_s = Type.evaluate(this.visProp.selection);
 
                 if (!A.isReal || !B.isReal || !C.isReal) {
                     this.dataX = [NaN];
@@ -336,8 +337,8 @@ define([
                 }
 
                 phi = Geometry.rad(A, B, C);
-                if ((this.visProp.selection === 'minor' && phi > Math.PI) ||
-                        (this.visProp.selection === 'major' && phi < Math.PI)) {
+                if ((vp_s === 'minor' && phi > Math.PI) ||
+                        (vp_s === 'major' && phi < Math.PI)) {
                     sgn = -1;
                 }
 
@@ -391,19 +392,22 @@ define([
         // Default hasPoint method. Documented in geometry element
         el.hasPointCurve = function (x, y) {
             var angle, alpha, beta,
-                prec = this.board.options.precision.hasPoint / (this.board.unitX),
+                prec,
                 checkPoint = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board),
                 r = this.Radius(),
                 dist = this.center.coords.distance(Const.COORDS_BY_USER, checkPoint),
-                has = (Math.abs(dist - r) < prec);
+                has,
+                vp_s = Type.evaluate(this.visProp.selection);
 
+            prec = this.board.options.precision.hasPoint / Math.min(this.board.unitX, this.board.unitY);
+            has = (Math.abs(dist - r) < prec);
             if (has) {
                 angle = Geometry.rad(this.point2, this.center, checkPoint.usrCoords.slice(1));
                 alpha = 0;
                 beta = Geometry.rad(this.point2, this.center, this.point3);
 
-                if ((this.visProp.selection === 'minor' && beta > Math.PI) ||
-                        (this.visProp.selection === 'major' && beta < Math.PI)) {
+                if ((vp_s === 'minor' && beta > Math.PI) ||
+                        (vp_s === 'major' && beta < Math.PI)) {
                     alpha = beta;
                     beta = 2 * Math.PI;
                 }
@@ -432,15 +436,16 @@ define([
                 dist = this.point1.coords.distance(Const.COORDS_BY_USER, checkPoint),
                 alpha,
                 beta,
-                has = (dist < r);
+                has = (dist < r),
+                vp_s = Type.evaluate(this.visProp.selection);
 
             if (has) {
                 angle = Geometry.rad(this.radiuspoint, this.center, checkPoint.usrCoords.slice(1));
                 alpha = 0.0;
                 beta = Geometry.rad(this.radiuspoint, this.center, this.anglepoint);
 
-                if ((this.visProp.selection === 'minor' && beta > Math.PI) ||
-                        (this.visProp.selection === 'major' && beta < Math.PI)) {
+                if ((vp_s === 'minor' && beta > Math.PI) ||
+                        (vp_s === 'major' && beta < Math.PI)) {
                     alpha = beta;
                     beta = 2 * Math.PI;
                 }
@@ -453,7 +458,8 @@ define([
         };
 
         el.hasPoint = function (x, y) {
-            if (this.visProp.highlightonsector || this.visProp.hasinnerpoints) {
+            if (Type.evaluate(this.visProp.highlightonsector) ||
+                    Type.evaluate(this.visProp.hasinnerpoints)) {
                 return this.hasPointSector(x, y);
             }
 
@@ -477,15 +483,16 @@ define([
                 p2c = this.point2.coords.usrCoords,
                 pmc = this.point1.coords.usrCoords,
                 bxminusax = p2c[1] - pmc[1],
-                byminusay = p2c[2] - pmc[2];
+                byminusay = p2c[2] - pmc[2],
+                vp_s = Type.evaluate(this.visProp.selection);
 
             // If this is uncommented, the angle label can not be dragged
             //if (Type.exists(this.label)) {
             //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
             //}
 
-            if ((this.visProp.selection === 'minor' && angle > Math.PI) ||
-                    (this.visProp.selection === 'major' && angle < Math.PI)) {
+            if ((vp_s === 'minor' && angle > Math.PI) ||
+                    (vp_s === 'major' && angle < Math.PI)) {
                 angle = -(2 * Math.PI - angle);
             }
 
@@ -576,7 +583,7 @@ define([
      *     p3 = board.create('point', [5.0, 3.0]),
      *
      *     a = board.create('circumcirclesector', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
  *   var board = JXG.JSXGraph.initBoard('695cf0d6-6d7a-4d4d-bfc9-34c6aa28cd04', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -641,7 +648,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('minorsector', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="af27ddcc-265f-428f-90dd-d31ace945800" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="af27ddcc-265f-428f-90dd-d31ace945800" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('af27ddcc-265f-428f-90dd-d31ace945800', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -679,7 +686,7 @@ define([
      * var p3 = board.create('point', [3.5, 1.0]);
      *
      * var a = board.create('majorsector', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="83c6561f-7561-4047-b98d-036248a00932" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="83c6561f-7561-4047-b98d-036248a00932" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('83c6561f-7561-4047-b98d-036248a00932', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -729,8 +736,8 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('angle', [p1, p2, p3]),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
-     * </pre><div class="jxgbox"id="a34151f9-bb26-480a-8d6e-9b8cbf789ae5" style="width: 300px; height: 300px;"></div>
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
+     * </pre><div class="jxgbox" id="a34151f9-bb26-480a-8d6e-9b8cbf789ae5" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('a34151f9-bb26-480a-8d6e-9b8cbf789ae5', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -739,7 +746,7 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('angle', [p1, p2, p3]),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
      * })();
      * </script><pre>
      *
@@ -757,7 +764,7 @@ define([
      *  a2 = board.create('angle', [li1, li2, 1, -1], { radius:2 });
      *
      *
-     * </pre><div class="jxgbox"id="3a667ddd-63dc-4594-b5f1-afac969b371f" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="3a667ddd-63dc-4594-b5f1-afac969b371f" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('3a667ddd-63dc-4594-b5f1-afac969b371f', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -849,11 +856,12 @@ define([
                     d = B.Dist(A),
                     ar,
                     phi,
-                    sgn = 1;
+                    sgn = 1,
+                    vp_s = Type.evaluate(this.visProp.selection);
 
                 phi = Geometry.rad(A, B, C);
-                if ((this.visProp.selection === 'minor' && phi > Math.PI) ||
-                        (this.visProp.selection === 'major' && phi < Math.PI)) {
+                if ((vp_s === 'minor' && phi > Math.PI) ||
+                        (vp_s === 'major' && phi < Math.PI)) {
                     sgn = -1;
                 }
 
@@ -1000,8 +1008,8 @@ define([
         } // end '3points'
 
         // GEONExT compatible labels.
-        if (JXG.exists(el.visProp.text)) {
-            el.label.setText(el.visProp.text);
+        if (Type.exists(el.visProp.text)) {
+            el.label.setText(Type.evaluate(el.visProp.text));
         }
 
         el.elType = 'angle';
@@ -1057,16 +1065,17 @@ define([
         };
 
         el.updateDataArray = function () {
-            var type = this.visProp.type,
-                deg = Geometry.trueAngle(this.point2, this.point1, this.point3);
+            var type = Type.evaluate(this.visProp.type),
+                deg = Geometry.trueAngle(this.point2, this.point1, this.point3),
+                vp_s = Type.evaluate(this.visProp.selection);
 
-            if ((this.visProp.selection === 'minor' && deg > 180.0) ||
-                    (this.visProp.selection === 'major' && deg < 180.0)) {
+            if ((vp_s === 'minor' && deg > 180.0) ||
+                    (vp_s === 'major' && deg < 180.0)) {
                 deg = 360.0 - deg;
             }
 
-            if (Math.abs(deg - 90.0) < this.visProp.orthosensitivity + Mat.eps) {
-                type = this.visProp.orthotype;
+            if (Math.abs(deg - 90.0) < Type.evaluate(this.visProp.orthosensitivity) + Mat.eps) {
+                type = Type.evaluate(this.visProp.orthotype);
             }
 
             if (type === 'none') {
@@ -1098,7 +1107,8 @@ define([
         attrsub = Type.copyAttributes(attributes, board.options, 'angle', 'dot');
         el.dot = board.create('point', [function () {
             var A, B, r, d, a2, co, si, mat,
-                point1, point2, point3;
+                point1, point2, point3,
+                vp_s;
 
             if (Type.exists(el.dot) && !el.dot.visProp.visible) {
                 return [0, 0];
@@ -1110,8 +1120,9 @@ define([
             d = Geometry.distance(A, B, 3);
             a2 = Geometry.rad(el.point2, el.point1, el.point3);
 
-            if ((el.visProp.selection === 'minor' && a2 > Math.PI) ||
-                    (el.visProp.selection === 'major' && a2 < Math.PI)) {
+            vp_s = Type.evaluate(el.visProp.selection);
+            if ((vp_s === 'minor' && a2 > Math.PI) ||
+                    (vp_s === 'major' && a2 < Math.PI)) {
                 a2 = -(2 * Math.PI - a2);
             }
             a2 *= 0.5;
@@ -1145,7 +1156,8 @@ define([
         // documented in GeometryElement
         el.getLabelAnchor = function () {
             var vec, dx = 12, dy = 12,
-                A, B, r, d, a2, co, si, mat;
+                A, B, r, d, a2, co, si, mat,
+                vp_s = Type.evaluate(el.visProp.selection);
 
             // If this is uncommented, the angle label can not be dragged
             //if (Type.exists(this.label)) {
@@ -1153,8 +1165,7 @@ define([
             //}
 
             if (Type.exists(this.label.visProp.fontSize)) {
-                dx = this.label.visProp.fontSize;
-                dy = this.label.visProp.fontSize;
+                dx = dy = Type.evaluate(this.label.visProp.fontSize);
             }
             dx /= this.board.unitX;
             dy /= this.board.unitY;
@@ -1164,8 +1175,8 @@ define([
             r = el.Radius();
             d = Geometry.distance(A, B, 3);
             a2 = Geometry.rad(el.point2, el.point1, el.point3);
-            if ((el.visProp.selection === 'minor' && a2 > Math.PI) ||
-                    (el.visProp.selection === 'major' && a2 < Math.PI)) {
+            if ((vp_s === 'minor' && a2 > Math.PI) ||
+                    (vp_s === 'major' && a2 < Math.PI)) {
                 a2 = -(2 * Math.PI - a2);
             }
             a2 *= 0.5;
@@ -1231,8 +1242,8 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2}),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
-     * </pre><div class="jxgbox"id="d0ab6d6b-63a7-48b2-8749-b02bb5e744f9" style="width: 300px; height: 300px;"></div>
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
+     * </pre><div class="jxgbox" id="d0ab6d6b-63a7-48b2-8749-b02bb5e744f9" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('d0ab6d6b-63a7-48b2-8749-b02bb5e744f9', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -1241,7 +1252,7 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('nonreflexangle', [p1, p2, p3], {radius: 2}),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
      * })();
      * </script><pre>
      */
@@ -1279,8 +1290,8 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2}),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
-     * </pre><div class="jxgbox"id="f2a577f2-553d-4f9f-a895-2d6d4b8c60e8" style="width: 300px; height: 300px;"></div>
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
+     * </pre><div class="jxgbox" id="f2a577f2-553d-4f9f-a895-2d6d4b8c60e8" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      * var board = JXG.JSXGraph.initBoard('f2a577f2-553d-4f9f-a895-2d6d4b8c60e8', {boundingbox: [-1, 7, 7, -1], axis: true, showcopyright: false, shownavigation: false}),
@@ -1289,7 +1300,7 @@ define([
      *     p3 = board.create('point', [1.5, 5.0]),
      *
      *     a = board.create('reflexangle', [p1, p2, p3], {radius: 2}),
-     *     t = board.create('text', [4, 4, function() { return a.Value().toFixed(2); }]);
+     *     t = board.create('text', [4, 4, function() { return JXG.toFixed(a.Value(), 2); }]);
      * })();
      * </script><pre>
      */
