@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -76,7 +76,7 @@ define([
      * @example
      * // Create a slider with values between 1 and 10, initial position is 5.
      * var s = board.create('slider', [[1, 2], [3, 2], [1, 5, 10]]);
-     * </pre><div class="jxgbox"id="cfb51cde-2603-4f18-9cc4-1afb452b374d" style="width: 200px; height: 200px;"></div>
+     * </pre><div class="jxgbox" id="cfb51cde-2603-4f18-9cc4-1afb452b374d" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   (function () {
      *     var board = JXG.JSXGraph.initBoard('cfb51cde-2603-4f18-9cc4-1afb452b374d', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -85,12 +85,12 @@ define([
      * </script><pre>
      * @example
      * // Create a slider taking integer values between 1 and 50. Initial value is 50.
-     * var s = board.create('slider', [[1, 3], [3, 1], [1, 10, 50]], {snapWidth: 1});
-     * </pre><div class="jxgbox"id="e17128e6-a25d-462a-9074-49460b0d66f4" style="width: 200px; height: 200px;"></div>
+     * var s = board.create('slider', [[1, 3], [3, 1], [0, 10, 50]], {snapWidth: 1, ticks: { drawLabels: true }});
+     * </pre><div class="jxgbox" id="e17128e6-a25d-462a-9074-49460b0d66f4" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   (function () {
      *     var board = JXG.JSXGraph.initBoard('e17128e6-a25d-462a-9074-49460b0d66f4', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
-     *     var s = board.create('slider', [[1, 3], [3, 1], [1, 10, 50]], {snapWidth: 1});
+     *     var s = board.create('slider', [[1, 3], [3, 1], [1, 10, 50]], {snapWidth: 1, ticks: { drawLabels: true }});
      *   })();
      * </script><pre>
      */
@@ -129,26 +129,6 @@ define([
         smax = parents[2][2];
         sdiff = smax - smin;
 
-        if (withTicks) {
-            attr = Type.copyAttributes(attributes, board.options, 'slider', 'ticks');
-            ticks  = 2;
-            ti = board.create('ticks', [
-                l1,
-                p2.Dist(p1) / ticks,
-
-                function (tick) {
-                    var dFull = p1.Dist(p2),
-                        d = p1.coords.distance(Const.COORDS_BY_USER, tick);
-
-                    if (dFull < Mat.eps) {
-                        return 0;
-                    }
-
-                    return d / dFull * sdiff + smin;
-                }
-            ], attr);
-        }
-
         startx = pos0[0] + (pos1[0] - pos0[0]) * (start - smin) / (smax - smin);
         starty = pos0[1] + (pos1[1] - pos0[1]) * (start - smin) / (smax - smin);
 
@@ -172,8 +152,12 @@ define([
          * @returns {Number}
          */
         p3.Value = function () {
-            var sdiff = this._smax - this._smin;
-            return p3.visProp.snapwidth === -1 ? this.position * sdiff + this._smin : Math.round((this.position * sdiff + this._smin) / this.visProp.snapwidth) * this.visProp.snapwidth;
+            var sdiff = this._smax - this._smin,
+                ev_sw = Type.evaluate(this.visProp.snapwidth);
+
+            return ev_sw === -1 ?
+                        this.position * sdiff + this._smin :
+                        Math.round((this.position * sdiff + this._smin) / ev_sw) * ev_sw;
         };
 
         p3.methodMap = Type.deepCopy(p3.methodMap, {
@@ -255,15 +239,29 @@ define([
                     return (p2.Y() - p1.Y()) * 0.05 + p2.Y();
                 },
                 function () {
-                    var n;
+                    var n,
+                        sl = Type.evaluate(p3.visProp.suffixlabel),
+                        ul = Type.evaluate(p3.visProp.unitlabel),
+                        pl = Type.evaluate(p3.visProp.postlabel);
 
-                    if (p3.name && p3.name !== '') {
+                    if (sl !== null) {
+                        n = sl;
+                    } else if (p3.name && p3.name !== '') {
                         n = p3.name + ' = ';
                     } else {
                         n = '';
                     }
 
-                    return n + (p3.Value()).toFixed(precision);
+                    n += Type.toFixed(p3.Value(), precision);
+
+                    if (ul !== null) {
+                        n += ul;
+                    }
+                    if (pl !== null) {
+                        n += pl;
+                    }
+
+                    return n;
                 }
             ], attr);
 
@@ -313,6 +311,41 @@ define([
         p3.highline = l2;
 
         if (withTicks) {
+            // Function to generate correct label texts
+
+            attr = Type.copyAttributes(attributes, board.options, 'slider', 'ticks');
+            if (!Type.exists(attr.generatelabeltext)) {
+                attr.generateLabelText = function(tick, zero, value) {
+                    var labelText,
+                        dFull = p3.point1.Dist(p3.point2),
+                        smin = p3._smin, smax = p3._smax,
+                        val = this.getDistanceFromZero(zero, tick) * (smax - smin) / dFull  + smin;
+
+                        if (dFull < Mat.eps || Math.abs(val) < Mat.eps) { // Point is zero
+                            labelText = '0';
+                        } else {
+                            labelText = this.formatLabelText(val);
+                        }
+                        return labelText;
+                };
+            }
+            ticks  = 2;
+            ti = board.create('ticks', [
+                p3.baseline,
+                p3.point1.Dist(p1) / ticks,
+
+                function (tick) {
+                    var dFull = p3.point1.Dist(p3.point2),
+                        d = p1p3.point1.coords.distance(Const.COORDS_BY_USER, tick);
+
+                    if (dFull < Mat.eps) {
+                        return 0;
+                    }
+
+                    return d / dFull * sdiff + smin;
+                }
+            ], attr);
+
             /**
              * Ticks give a rough indication about the slider's current value.
              * @memberOf Slider.prototype
@@ -350,39 +383,41 @@ define([
             baseLine: l1,
             highLine: l2
         };
+        p3.inherits.push(p1, p2, l1, l2);
 
         if (withTicks) {
             ti.dump = false;
             p3.subs.ticks = ti;
+            p3.inherits.push(ti);
         }
 
         // Save the visibility attribute of the sub-elements
-        for (el in p3.subs) {
-            p3.subs[el].status = {
-                visible: p3.subs[el].visProp.visible
-            };
-        }
+        // for (el in p3.subs) {
+        //     p3.subs[el].status = {
+        //         visible: p3.subs[el].visProp.visible
+        //     };
+        // }
 
-        p3.hideElement = function () {
-            var el;
-            GeometryElement.prototype.hideElement.call(this);
+        // p3.hideElement = function () {
+        //     var el;
+        //     GeometryElement.prototype.hideElement.call(this);
+        //
+        //     for (el in this.subs) {
+        //         // this.subs[el].status.visible = this.subs[el].visProp.visible;
+        //         this.subs[el].hideElement();
+        //     }
+        // };
 
-            for (el in this.subs) {
-                this.subs[el].status.visible = this.subs[el].visProp.visible;
-                this.subs[el].hideElement();
-            }
-        };
-
-        p3.showElement = function () {
-            var el;
-            GeometryElement.prototype.showElement.call(this);
-
-            for (el in this.subs) {
-                if (this.subs[el].status.visible) {
-                    this.subs[el].showElement();
-                }
-            }
-        };
+//         p3.showElement = function () {
+//             var el;
+//             GeometryElement.prototype.showElement.call(this);
+//
+//             for (el in this.subs) {
+// //                if (this.subs[el].status.visible) {
+//                 this.subs[el].showElement();
+// //                }
+//             }
+//         };
 
         return p3;
     };
