@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2011
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -158,25 +158,24 @@ define([
         /**
          * Initialise a new board.
          * @param {String} box Html-ID to the Html-element in which the board is painted.
-         * @param {Object} attributes An object that sets some of the board properties. Most of these properties can be set via JXG.Options. Valid properties are
-         * <ul>
-         *     <li><b>boundingbox</b>: An array containing four numbers describing the left, top, right and bottom boundary of the board in user coordinates</li>
-         *     <li><b>keepaspectratio</b>: If <tt>true</tt>, the bounding box is adjusted to the same aspect ratio as the aspect ratio of the div containing the board.</li>
-         *     <li><b>showCopyright</b>: Show the copyright string in the top left corner.</li>
-         *     <li><b>showNavigation</b>: Show the navigation buttons in the bottom right corner.</li>
-         *     <li><b>zoom</b>: Allow the user to zoom with the mouse wheel or the two-fingers-zoom gesture.</li>
-         *     <li><b>pan</b>: Allow the user to pan with shift+drag mouse or two-fingers-pan gesture.</li>
-         *     <li><b>axis</b>: If set to true, show the axis. Can also be set to an object that is given to both axes as an attribute object.</li>
-         *     <li><b>grid</b>: If set to true, shows the grid. Can also bet set to an object that is given to the grid as its attribute object.</li>
-         *     <li><b>registerEvents</b>: Register mouse / touch events.</li>
-         * </ul>
+         * @param {Object} attributes An object that sets some of the board properties. Most of these properties can be set via JXG.Options.
+         * @param {Array} [attributes.boundingbox=[-5, 5, 5, -5]] An array containing four numbers describing the left, top, right and bottom boundary of the board in user coordinates
+         * @param {Boolean} [attributes.keepaspectratio=false] If <tt>true</tt>, the bounding box is adjusted to the same aspect ratio as the aspect ratio of the div containing the board.
+         * @param {Boolean} [attributes.showCopyright=false] Show the copyright string in the top left corner.
+         * @param {Boolean} [attributes.showNavigation=false] Show the navigation buttons in the bottom right corner.
+         * @param {Object} [attributes.zoom] Allow the user to zoom with the mouse wheel or the two-fingers-zoom gesture.
+         * @param {Object} [attributes.pan] Allow the user to pan with shift+drag mouse or two-fingers-pan gesture.
+         * @param {Boolean} [attributes.axis=false] If set to true, show the axis. Can also be set to an object that is given to both axes as an attribute object.
+         * @param {Boolean|Object} [attributes.grid] If set to true, shows the grid. Can also bet set to an object that is given to the grid as its attribute object.
+         * @param {Boolean} [attributes.registerEvents=true] Register mouse / touch events.
          * @returns {JXG.Board} Reference to the created board.
          */
         initBoard: function (box, attributes) {
             var originX, originY, unitX, unitY,
                 renderer,
                 w, h, dimensions,
-                bbox, attr, axattr,
+                bbox, attr, axattr, axattr_x, axattr_y,
+                defaultaxesattr,
                 selectionattr,
                 board;
 
@@ -187,6 +186,7 @@ define([
             attr.zoom = Type.copyAttributes(attr, Options, 'board', 'zoom');
             attr.pan = Type.copyAttributes(attr, Options, 'board', 'pan');
             attr.selection = Type.copyAttributes(attr, Options, 'board', 'selection');
+            attr.navbar = Type.copyAttributes(attr.navbar, Options, 'navbar');
 
             dimensions = Env.getDimensions(box, attr.document);
 
@@ -225,7 +225,12 @@ define([
             renderer = this.initRenderer(box, dimensions, attr.document, attr.renderer);
 
             // create the board
-            board = new Board(box, renderer, attr.id, [originX, originY], attr.zoomfactor * attr.zoomx, attr.zoomfactor * attr.zoomy, unitX, unitY, dimensions.width, dimensions.height, attr);
+            board = new Board(box, renderer, attr.id, [originX, originY],
+                        attr.zoomfactor * attr.zoomx,
+                        attr.zoomfactor * attr.zoomy,
+                        unitX, unitY,
+                        dimensions.width, dimensions.height,
+                        attr);
 
             JXG.boards[board.id] = board;
 
@@ -237,10 +242,22 @@ define([
             board.initInfobox();
 
             if (attr.axis) {
-                axattr = typeof attr.axis === 'object' ? attr.axis : {ticks: {drawZero: true}};
+                axattr = typeof attr.axis === 'object' ? attr.axis : {};
+
+                // The defaultAxes attributes are overwritten by user supplied axis object.
+                axattr_x = Type.deepCopy(Options.board.defaultAxes.x, axattr);
+                axattr_y = Type.deepCopy(Options.board.defaultAxes.y, axattr);
+                // The user supplied defaultAxes attributes are merged in.
+                if (attr.defaultaxes.x) {
+                    axattr_x = Type.deepCopy(axattr_x, attr.defaultaxes.x);
+                }
+                if (attr.defaultaxes.y) {
+                    axattr_y = Type.deepCopy(axattr_y, attr.defaultaxes.y);
+                }
+
                 board.defaultAxes = {};
-                board.defaultAxes.x = board.create('axis', [[0, 0], [1, 0]], axattr);
-                board.defaultAxes.y = board.create('axis', [[0, 0], [0, 1]], axattr);
+                board.defaultAxes.x = board.create('axis', [[0, 0], [1, 0]], axattr_x);
+                board.defaultAxes.y = board.create('axis', [[0, 0], [0, 1]], axattr_y);
             }
 
             if (attr.grid) {
@@ -255,7 +272,7 @@ define([
             }
             */
 
-            board.renderer.drawZoomBar(board);
+            board.renderer.drawZoomBar(board, attr.navbar);
             board.unsuspendUpdate();
 
             return board;
@@ -286,6 +303,7 @@ define([
             attr.zoom = Type.copyAttributes(attributes, Options, 'board', 'zoom');
             attr.pan = Type.copyAttributes(attributes, Options, 'board', 'pan');
             attr.selection = Type.copyAttributes(attr, Options, 'board', 'selection');
+            attr.navbar = Type.copyAttributes(attr.navbar, Options, 'navbar');
 
             dimensions = Env.getDimensions(box, attr.document);
             renderer = this.initRenderer(box, dimensions, attr.document);
@@ -300,7 +318,7 @@ define([
             selectionattr = Type.copyAttributes(attr, Options, 'board', 'selection');
 	        board.selectionPolygon = board.create('polygon', [[0, 0], [0, 0], [0, 0], [0, 0]], selectionattr);
 
-            board.renderer.drawZoomBar(board);
+            board.renderer.drawZoomBar(board, attr.navbar);
             JXG.boards[board.id] = board;
 
             return board;
@@ -331,6 +349,7 @@ define([
             attr.zoom = Type.copyAttributes(attributes, Options, 'board', 'zoom');
             attr.pan = Type.copyAttributes(attributes, Options, 'board', 'pan');
             attr.selection = Type.copyAttributes(attr, Options, 'board', 'selection');
+            attr.navbar = Type.copyAttributes(attr.navbar, Options, 'navbar');
 
             dimensions = Env.getDimensions(box, attr.document);
             renderer = this.initRenderer(box, dimensions, attr.document);
@@ -345,7 +364,7 @@ define([
             selectionattr = Type.copyAttributes(attr, Options, 'board', 'selection');
 	        board.selectionPolygon = board.create('polygon', [[0, 0], [0, 0], [0, 0], [0, 0]], selectionattr);
 
-            board.renderer.drawZoomBar(board);
+            board.renderer.drawZoomBar(board, attr.navbar);
             JXG.boards[board.id] = board;
 
             return board;
@@ -439,7 +458,9 @@ define([
             for (i = 0; i < scripts.length; i++) {
                 type = scripts[i].getAttribute('type', false);
 
-                if (Type.exists(type) && (type.toLowerCase() === 'text/jessiescript' || type.toLowerCase() === 'jessiescript' || type.toLowerCase() === 'text/jessiecode' || type.toLowerCase() === 'jessiecode')) {
+                if (Type.exists(type) &&
+                    (type.toLowerCase() === 'text/jessiescript' || type.toLowerCase() === 'jessiescript' ||
+                     type.toLowerCase() === 'text/jessiecode' || type.toLowerCase() === 'jessiecode')) {
                     width = scripts[i].getAttribute('width', false) || '500px';
                     height = scripts[i].getAttribute('height', false) || '500px';
                     bbox = scripts[i].getAttribute('boundingbox', false) || '-5, 5, 5, -5';
