@@ -1,5 +1,5 @@
 /*
- Copyright 2008-2016
+ Copyright 2008-2017
  Matthias Ehmann,
  Michael Gerhaeuser,
  Carsten Miller,
@@ -144,15 +144,8 @@
             // for printing, e.g. trim them with toFixed()
                 pn = function (v) {
                     if (options.toFixed > 0) {
-                        // toFixed is a method if Number since JavaScript 1.5, resp. ECMAScript (ECMA 262) 3rd Edition
-                        // introduced somewhat around 1999/2000. It is part of every recent version of every major browser.
-                        // See this table: http://en.wikipedia.org/wiki/JavaScript#Versions
-                        // The only possible explanation is that v might not be a number but a string or something else.
-                        // In that case the caller should be fixed instead of rendering this function completely useless.
-
-                        // make sure v is a float (or NaN if it neither is a float nor could be converted to float).
                         v = parseFloat(v);
-                        v = v.toFixed(options.toFixed); // toFixed is not a member function of the Number class ...
+                        return JXG.toFixed(v, options.toFixed);
                     }
 
                     return v;
@@ -910,9 +903,9 @@
                     }
                     set_str += ' ]';
                     set_str += ', name: \'\'';
-                    set_str += ', fillColor: \'' + JXG.Options.intersection.fillColor + '\'';
-                    set_str += ', strokeColor: \'' + JXG.Options.intersection.strokeColor + '\'';
-                    set_str += ', opacity: \'' + JXG.Options.intersection.opacity + '\'';
+                    // set_str += ', fillColor: \'' + JXG.Options.regularpolygon.fillColor + '\'';
+                    // set_str += ', strokeColor: \'' + JXG.Options.intersection.strokeColor + '\'';
+                    // set_str += ', opacity: \'' + JXG.Options.intersection.opacity + '\'';
                     set_str += '>>, ' + attrid;
                     set_str += ' fillOpacity: ' + JXG.Options.opacityLevel;
                     set_str += ', hasInnerPoints_Org: ' + JXG.Options.polygon.hasInnerPoints;
@@ -964,10 +957,11 @@
                     set_str = assign + 'slopetriangle(' + step.src_ids.join(', ') + ') <<';
                     set_str += attrid + ' name: \'\',';
                     set_str += 'borders: <<ids: [\'' + step.dest_sub_ids[4] + '\', \'' + step.dest_sub_ids[5] + '\', \'' + step.dest_sub_ids[6] + '\']>>,';
-                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\', priv: true >>, baseline: <<id: \'' + step.dest_sub_ids[1] + '\', priv: true >>,';
-                    set_str += 'glider: <<id: \'' + step.dest_sub_ids[2] + '\', priv: true >>, toppoint: <<id: \'' + step.dest_sub_ids[3] + '\', priv: true >>';
+                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\', priv: false >>, baseline: <<id: \'' + step.dest_sub_ids[1] + '\', priv: true >>,';
+                    set_str += 'glider: <<id: \'' + step.dest_sub_ids[2] + '\', priv: false >>, toppoint: <<id: \'' + step.dest_sub_ids[3] + '\', priv: false >>';
                     if (step.dest_sub_ids.length === 8) {  // The test is needed for backwards compatibility
-                        set_str += ', tangent: <<id: \'' + step.dest_sub_ids[2] + '\', priv: true, point1: <<priv: true >>, point2: <<priv: true >> >>';
+                        set_str += ', tangent: <<id: \'' + step.dest_sub_ids[2] +
+                                    '\', priv: true, point1: <<priv: true >>, point2: <<priv: true >> >>';
                     }
                     set_str += '>>;';
                     reset_str = 'delete ' + step.dest_id + '; ';
