@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -78,14 +78,17 @@ define([
         if (Env.isBrowser) {
             this.container = container;
             this.container.style.MozUserSelect = 'none';
+            this.container.style.userSelect = 'none';
 
             this.container.style.overflow = 'hidden';
             if (this.container.style.position === '') {
                 this.container.style.position = 'relative';
             }
 
-            this.container.innerHTML = ['<canvas id="', this.canvasId, '" width="', dim.width, 'px" height="',
-                dim.height, 'px"><', '/canvas>'].join('');
+            this.container.innerHTML = ['<canvas id="', this.canvasId,
+                '" width="', dim.width,
+                'px" height="', dim.height,
+                'px"><', '/canvas>'].join('');
             this.canvasRoot = this.container.ownerDocument.getElementById(this.canvasId);
             this.context =  this.canvasRoot.getContext('2d');
         } else if (Env.isNode()) {
@@ -132,14 +135,14 @@ define([
 
         /**
          * Sets the fill color and fills an area.
-         * @param {JXG.GeometryElement} element An arbitrary JSXGraph element, preferably one with an area.
+         * @param {JXG.GeometryElement} el An arbitrary JSXGraph element, preferably one with an area.
          * @private
          */
-        _fill: function (element) {
+        _fill: function (el) {
             var context = this.context;
 
             context.save();
-            if (this._setColor(element, 'fill')) {
+            if (this._setColor(el, 'fill')) {
                 context.fill();
             }
             context.restore();
@@ -185,27 +188,27 @@ define([
          * Sets color and opacity for filling and stroking.
          * type is the attribute from visProp and targetType the context[targetTypeStyle].
          * This is necessary, because the fill style of a text is set by the stroke attributes of the text element.
-         * @param {JXG.GeometryElement} element Any JSXGraph element.
+         * @param {JXG.GeometryElement} el Any JSXGraph element.
          * @param {String} [type='stroke'] Either <em>fill</em> or <em>stroke</em>.
          * @param {String} [targetType=type] (optional) Either <em>fill</em> or <em>stroke</em>.
          * @returns {Boolean} If the color could be set, <tt>true</tt> is returned.
          * @private
          */
-        _setColor: function (element, type, targetType) {
+        _setColor: function (el, type, targetType) {
             var hasColor = true, isTrace = false,
-                ev = element.visProp, hl,
+                ev = el.visProp, hl, sw,
                 rgba, rgbo, c, o, oo;
 
             type = type || 'stroke';
             targetType = targetType || type;
 
-            if (!Type.exists(element.board) || !Type.exists(element.board.highlightedObjects)) {
+            if (!Type.exists(el.board) || !Type.exists(el.board.highlightedObjects)) {
                 // This case handles trace elements.
                 // To make them work, we simply neglect highlighting.
                 isTrace = true;
             }
 
-            if (!isTrace && Type.exists(element.board.highlightedObjects[element.id])) {
+            if (!isTrace && Type.exists(el.board.highlightedObjects[el.id])) {
                 hl = 'highlight';
             } else {
                 hl = '';
@@ -234,36 +237,43 @@ define([
             } else {
                 hasColor = false;
             }
-            if (type === 'stroke' && !isNaN(parseFloat(ev.strokewidth))) {
-                if (parseFloat(ev.strokewidth) === 0) {
+
+            sw = parseFloat(Type.evaluate(ev.strokewidth));
+            if (type === 'stroke' && !isNaN(sw)) {
+                if (sw === 0) {
                     this.context.globalAlpha = 0;
                 } else {
-                    this.context.lineWidth = parseFloat(ev.strokewidth);
+                    this.context.lineWidth = sw;
                 }
             }
+
+            if (type === 'stroke' && ev.linecap !== undefined && ev.linecap !== '') {
+                this.context.lineCap = ev.linecap;
+            }
+
             return hasColor;
         },
 
-
         /**
          * Sets color and opacity for drawing paths and lines and draws the paths and lines.
-         * @param {JXG.GeometryElement} element An JSXGraph element with a stroke.
+         * @param {JXG.GeometryElement} el An JSXGraph element with a stroke.
          * @private
          */
-        _stroke: function (element) {
-            var context = this.context;
+        _stroke: function (el) {
+            var context = this.context,
+                ev_dash = Type.evaluate(el.visProp.dash);
 
             context.save();
 
-            if (element.visProp.dash > 0) {
+            if (ev_dash > 0) {
                 if (context.setLineDash) {
-                    context.setLineDash(this.dashArray[element.visProp.dash]);
+                    context.setLineDash(this.dashArray[ev_dash]);
                 }
             } else {
                 this.context.lineDashArray = [];
             }
 
-            if (this._setColor(element, 'stroke')) {
+            if (this._setColor(el, 'stroke')) {
                 context.stroke();
             }
 
@@ -298,15 +308,15 @@ define([
 
         // documented in AbstractRenderer
         drawPoint: function (el) {
-            var f = el.visProp.face,
-                size = el.visProp.size,
+            var f = Type.evaluate(el.visProp.face),
+                size = Type.evaluate(el.visProp.size),
                 scr = el.coords.scrCoords,
                 sqrt32 = size * Math.sqrt(3) * 0.5,
                 s05 = size * 0.5,
-                stroke05 = parseFloat(el.visProp.strokewidth) / 2.0,
+                stroke05 = parseFloat(Type.evaluate(el.visProp.strokewidth)) / 2.0,
                 context = this.context;
 
-            if (!el.visProp.visible) {
+            if (!el.visPropCalc.visible) {
                 return;
             }
 
@@ -425,49 +435,33 @@ define([
 
         // documented in AbstractRenderer
         drawLine: function (el) {
-            var s, d, d1x, d1y, d2x, d2y,
-                scr1 = new Coords(Const.COORDS_BY_USER, el.point1.coords.usrCoords, el.board),
-                scr2 = new Coords(Const.COORDS_BY_USER, el.point2.coords.usrCoords, el.board),
-                margin = null;
+            var obj,
+                c1 = new Coords(Const.COORDS_BY_USER, el.point1.coords.usrCoords, el.board),
+                c2 = new Coords(Const.COORDS_BY_USER, el.point2.coords.usrCoords, el.board),
+                margin = null,
+                ev_fa = Type.evaluate(el.visProp.firstarrow),
+                ev_la = Type.evaluate(el.visProp.lastarrow);
 
-            if (!el.visProp.visible) {
+            if (!el.visPropCalc.visible) {
                 return;
             }
 
-            if (el.visProp.firstarrow || el.visProp.lastarrow) {
+            if (ev_fa || ev_la) {
                 margin = -4;
             }
-            Geometry.calcStraight(el, scr1, scr2, margin);
+            Geometry.calcStraight(el, c1, c2, margin);
 
-            d1x = d1y = d2x = d2y = 0.0;
-            /*
-               Handle arrow heads.
-
-               The arrow head is an equilateral triangle with base length 10 and height 10.
-               These 10 units are scaled to strokeWidth*3 pixels or minimum 10 pixels.
-            */
-            s = Math.max(parseInt(el.visProp.strokewidth, 10) * 3, 10);
-            if (el.visProp.lastarrow) {
-                d = scr1.distance(Const.COORDS_BY_SCREEN, scr2);
-                if (d > Mat.eps) {
-                    d2x = (scr2.scrCoords[1] - scr1.scrCoords[1]) * s / d;
-                    d2y = (scr2.scrCoords[2] - scr1.scrCoords[2]) * s / d;
-                }
-            }
-            if (el.visProp.firstarrow) {
-                d = scr1.distance(Const.COORDS_BY_SCREEN, scr2);
-                if (d > Mat.eps) {
-                    d1x = (scr2.scrCoords[1] - scr1.scrCoords[1]) * s / d;
-                    d1y = (scr2.scrCoords[2] - scr1.scrCoords[2]) * s / d;
-                }
-            }
+            obj = this.getPositionArrowHead(el, c1, c2);
 
             this.context.beginPath();
-            this.context.moveTo(scr1.scrCoords[1] + d1x, scr1.scrCoords[2] + d1y);
-            this.context.lineTo(scr2.scrCoords[1] - d2x, scr2.scrCoords[2] - d2y);
+            this.context.moveTo(obj.c1.scrCoords[1] + obj.d1x, obj.c1.scrCoords[2] + obj.d1y);
+            this.context.lineTo(obj.c2.scrCoords[1] - obj.d2x, obj.c2.scrCoords[2] - obj.d2y);
             this._stroke(el);
 
-            this.makeArrows(el, scr1, scr2);
+            if ((ev_fa && obj.sFirst > 0) ||
+                (ev_la && obj.sLast > 0)) {
+                this.makeArrows(el, obj.c1, obj.c2);
+            }
         },
 
         // documented in AbstractRenderer
@@ -502,7 +496,7 @@ define([
                 if (ticks.ticks[i].major &&
                         (ticks.board.needsFullUpdate || ticks.needsRegularUpdate) &&
                         ticks.labels[i] &&
-                        ticks.labels[i].visProp.visible) {
+                        ticks.labels[i].visPropCalc.visible) {
                     this.updateText(ticks.labels[i]);
                 }
             }
@@ -516,11 +510,14 @@ define([
 
         // documented in AbstractRenderer
         drawCurve: function (el) {
-            if (el.visProp.handdrawing) {
+            if (Type.evaluate(el.visProp.handdrawing)) {
                 this.updatePathStringBezierPrim(el);
             } else {
                 this.updatePathStringPrim(el);
             }
+            if (el.numberPoints > 1) {
+                this.makeArrows(el);
+            }
         },
 
         // documented in AbstractRenderer
@@ -595,45 +592,40 @@ define([
 
         // already documented in JXG.AbstractRenderer
         drawInternalText: function (el) {
-            var fs, context = this.context;
+            var ev_fs = Type.evaluate(el.visProp.fontsize),
+                ev_ax = Type.evaluate(el.visProp.anchorx),
+                ev_ay = Type.evaluate(el.visProp.anchory),
+                context = this.context;
 
             context.save();
-            // el.rendNode.setAttributeNS(null, "class", el.visProp.cssclass);
-            if (this._setColor(el, 'stroke', 'fill') && !isNaN(el.coords.scrCoords[1] + el.coords.scrCoords[2])) {
-                if (el.visProp.fontsize) {
-                    if (Type.isFunction(el.visProp.fontsize)) {
-                        fs = el.visProp.fontsize();
-                        context.font = (fs > 0 ? fs : 0) + 'px Arial';
-                    } else {
-                        context.font = (el.visProp.fontsize) + 'px Arial';
-                    }
-                }
+            if (this._setColor(el, 'stroke', 'fill') &&
+                    !isNaN(el.coords.scrCoords[1] + el.coords.scrCoords[2])) {
+                context.font = (ev_fs > 0 ? ev_fs : 0) + 'px Arial';
 
                 this.transformImage(el, el.transformations);
-                if (el.visProp.anchorx === 'left') {
+                if (ev_ax === 'left') {
                     context.textAlign = 'left';
-                } else if (el.visProp.anchorx === 'right') {
+                } else if (ev_ax === 'right') {
                     context.textAlign = 'right';
-                } else if (el.visProp.anchorx === 'middle') {
+                } else if (ev_ax === 'middle') {
                     context.textAlign = 'center';
                 }
-                if (el.visProp.anchory === 'bottom') {
+                if (ev_ay === 'bottom') {
                     context.textBaseline = 'bottom';
-                } else if (el.visProp.anchory === 'top') {
+                } else if (ev_ay === 'top') {
                     context.textBaseline = 'top';
-                } else if (el.visProp.anchory === 'middle') {
+                } else if (ev_ay === 'middle') {
                     context.textBaseline = 'middle';
                 }
                 context.fillText(el.plaintext, el.coords.scrCoords[1], el.coords.scrCoords[2]);
             }
             context.restore();
-
             return null;
         },
 
         // already documented in JXG.AbstractRenderer
-        updateInternalText: function (element) {
-            this.drawInternalText(element);
+        updateInternalText: function (el) {
+            this.drawInternalText(el);
         },
 
         // documented in JXG.AbstractRenderer
@@ -663,7 +655,7 @@ define([
                     oo = o * rgbo[1];
                 }
                 node = el.rendNode;
-                if (el.elementClass === Const.OBJECT_CLASS_TEXT && el.visProp.display === 'html') {
+                if (el.elementClass === Const.OBJECT_CLASS_TEXT && Type.evaluate(el.visProp.display) === 'html') {
                     node.style.color = c;
                     node.style.opacity = oo;
                 }
@@ -763,54 +755,107 @@ define([
         // documented in AbstractRenderer
         makeArrows: function (el, scr1, scr2) {
             // not done yet for curves and arcs.
-            /*
             var x1, y1, x2, y2, ang,
-                w = Math.min(el.visProp.strokewidth / 2, 3),
-                arrowHead = [
-                    [ 2, 0],
-                    [ -10, -4 * w],
-                    [ -10, 4 * w],
-                    [ 2, 0 ]
-                ],
-                arrowTail = [
-                    [ -2, 0],
-                    [ 10, -4 * w],
-                    [ 10, 4 * w]
-                ],
-                context = this.context;
-            */
-            var x1, y1, x2, y2, ang,
-                w = Math.max(el.visProp.strokewidth * 3, 10),
-                arrowHead = [
-                    [ -w, -w * 0.5],
-                    [ 0.0,     0.0],
-                    [ -w,  w * 0.5]
-                ],
-                arrowTail = [
-                    [ w,   -w * 0.5],
-                    [ 0.0,      0.0],
-                    [ w,    w * 0.5]
-                ],
-                context = this.context;
+                size,
+                w = Type.evaluate(el.visProp.strokewidth),
+                arrowHead,
+                arrowTail,
+                context = this.context,
+                type,
+                ev_fa = Type.evaluate(el.visProp.firstarrow),
+                ev_la = Type.evaluate(el.visProp.lastarrow);
 
-            if (el.visProp.strokecolor !== 'none' && (el.visProp.lastarrow || el.visProp.firstarrow)) {
+            if (Type.evaluate(el.visProp.strokecolor) !== 'none' &&
+                    (ev_fa || ev_la)) {
                 if (el.elementClass === Const.OBJECT_CLASS_LINE) {
                     x1 = scr1.scrCoords[1];
                     y1 = scr1.scrCoords[2];
                     x2 = scr2.scrCoords[1];
                     y2 = scr2.scrCoords[2];
                 } else {
+                    x1 = el.points[0].scrCoords[1];
+                    y1 = el.points[0].scrCoords[2];
+                    x2 = el.points[el.points.length - 1].scrCoords[1];
+                    y2 = el.points[el.points.length - 1].scrCoords[2];
                     return;
                 }
 
+                if (ev_fa &&
+                    Type.exists(ev_fa.type)) {
+
+                    if (Type.exists(ev_fa.size)) {
+                        size = Type.evaluate(ev_fa.size);
+                    } else {
+                        size = 3;
+                    }
+                    w *= size;
+
+                    type = Type.evaluate(ev_fa.type);
+                    if (type === 2) {
+                        arrowTail = [
+                                [ w,      -w * 0.5],
+                                [ 0.0,         0.0],
+                                [ w,       w * 0.5],
+                                [ w * 0.5,     0.0],
+                            ];
+                    } else if (type === 3) {
+                        arrowTail = [
+                                [ w / 3.0,   -w * 0.5],
+                                [ 0.0,       -w * 0.5],
+                                [ 0.0,        w * 0.5],
+                                [ w / 3.0,    w * 0.5]
+                            ];
+                    } else {
+                        arrowTail = [
+                            [ w,   -w * 0.5],
+                            [ 0.0,      0.0],
+                            [ w,    w * 0.5]
+                        ];
+                    }
+
+                }
+                if (ev_la &&
+                    Type.exists(ev_la.type)) {
+
+                    if (Type.exists(ev_la.size)) {
+                        size = Type.evaluate(ev_la.size);
+                    } else {
+                        size = 3;
+                    }
+                    w *= size;
+
+                    type = Type.evaluate(ev_la.type);
+                    if (type === 2) {
+                        arrowHead = [
+                            [ -w, -w * 0.5],
+                            [ 0.0,     0.0],
+                            [ -w,  w * 0.5],
+                            [ -w * 0.5, 0.0]
+                        ];
+                    } else if (type === 3) {
+                        arrowHead = [
+                                [-w / 3.0,   -w * 0.5],
+                                [ 0.0,       -w * 0.5],
+                                [ 0.0,        w * 0.5],
+                                [-w / 3.0,    w * 0.5]
+                            ];
+                    } else {
+                        arrowHead = [
+                            [ -w, -w * 0.5],
+                            [ 0.0,     0.0],
+                            [ -w,  w * 0.5]
+                        ];
+                    }
+                }
+
                 context.save();
                 if (this._setColor(el, 'stroke', 'fill')) {
                     ang = Math.atan2(y2 - y1, x2 - x1);
-                    if (el.visProp.lastarrow) {
+                    if (ev_la) {
                         this._drawFilledPolygon(this._translateShape(this._rotateShape(arrowHead, ang), x2, y2));
                     }
 
-                    if (el.visProp.firstarrow) {
+                    if (ev_fa) {
                         this._drawFilledPolygon(this._translateShape(this._rotateShape(arrowTail, ang), x1, y1));
                     }
                 }
@@ -826,7 +871,6 @@ define([
                 symbc = 'C',
                 nextSymb = symbm,
                 maxSize = 5000.0,
-                //isNotPlot = (el.visProp.curvetype !== 'plot'),
                 context = this.context;
 
             if (el.numberPoints <= 0) {
@@ -903,8 +947,8 @@ define([
                 symbl = 'C',
                 nextSymb = symbm,
                 maxSize = 5000.0,
-                f = el.visProp.strokewidth,
-                isNoPlot = (el.visProp.curvetype !== 'plot'),
+                f = Type.evaluate(el.visProp.strokewidth),
+                isNoPlot = (Type.evaluate(el.visProp.curvetype) !== 'plot'),
                 context = this.context;
 
             if (el.numberPoints <= 0) {
@@ -970,7 +1014,7 @@ define([
                 context = this.context,
                 isReal = true;
 
-            if (len <= 0 || !el.visProp.visible) {
+            if (len <= 0 || !el.visPropCalc.visible) {
                 return;
             }
 
@@ -997,12 +1041,27 @@ define([
             }
         },
 
-        /* **************************
+        /***************************
          *  Set Attributes
-         * **************************/
+         **************************
+         */
+
+         // already documented in JXG.AbstractRenderer
+         display: function(el, val) {
+             if (el && el.rendNode) {
+                 el.visPropOld.visible = val;
+                 if (val) {
+                     el.rendNode.style.visibility = "inherit";
+                 } else {
+                     el.rendNode.style.visibility = "hidden";
+                 }
+             }
+         },
 
         // documented in AbstractRenderer
         show: function (el) {
+            JXG.deprecated('Board.renderer.show()', 'Board.renderer.display()');
+
             if (Type.exists(el.rendNode)) {
                 el.rendNode.style.visibility = "inherit";
             }
@@ -1010,6 +1069,8 @@ define([
 
         // documented in AbstractRenderer
         hide: function (el) {
+            JXG.deprecated('Board.renderer.hide()', 'Board.renderer.display()');
+
             if (Type.exists(el.rendNode)) {
                 el.rendNode.style.visibility = "hidden";
             }
@@ -1040,7 +1101,7 @@ define([
 
         // documented in AbstractRenderer
         highlight: function (obj) {
-            if (obj.elementClass === Const.OBJECT_CLASS_TEXT && obj.visProp.display === 'html') {
+            if (obj.elementClass === Const.OBJECT_CLASS_TEXT && Type.evaluate(obj.visProp.display) === 'html') {
                 this.updateTextStyle(obj, true);
             } else {
                 obj.board.prepareUpdate();
@@ -1053,7 +1114,7 @@ define([
 
         // documented in AbstractRenderer
         noHighlight: function (obj) {
-            if (obj.elementClass === Const.OBJECT_CLASS_TEXT && obj.visProp.display === 'html') {
+            if (obj.elementClass === Const.OBJECT_CLASS_TEXT && Type.evaluate(obj.visProp.display) === 'html') {
                 this.updateTextStyle(obj, false);
             } else {
                 obj.board.prepareUpdate();
@@ -1089,12 +1150,17 @@ define([
                 this.canvasRoot.style.width = parseFloat(w) + 'px';
                 this.canvasRoot.style.height = parseFloat(h) + 'px';
 
-                this.canvasRoot.setAttribute('width', parseFloat(w) + 'px');
-                this.canvasRoot.setAttribute('height', parseFloat(h) + 'px');
+                this.canvasRoot.setAttribute('width', (2 * parseFloat(w)) + 'px');
+                this.canvasRoot.setAttribute('height',(2 * parseFloat(h)) + 'px');
             } else {
-                this.canvasRoot.width = parseFloat(w);
-                this.canvasRoot.height = parseFloat(h);
+                this.canvasRoot.width = 2 * parseFloat(w);
+                this.canvasRoot.height = 2 * parseFloat(h);
             }
+            this.context = this.canvasRoot.getContext('2d');
+            // The width and height of the canvas is set to twice the CSS values,
+            // followed by an appropiate scaling.
+            // See http://stackoverflow.com/questions/22416462/canvas-element-with-blurred-lines
+            this.context.scale(2, 2);
         },
 
         removeToInsertLater: function () {
