@@ -485,17 +485,34 @@ define(['jxg', 'renderer/abstract'], function (JXG, AbstractRenderer) {
          */
         setPropertyPrim: function (node, key, val) { /* stub */ },
 
+        /**
+         * Shows or hides an element on the canvas; Only a stub, requires implementation in the derived renderer.
+         * @param {JXG.GeometryElement} element Reference to the object that has to appear.
+         * @param {Boolean} value true to show the element, false to hide the element.
+         */
+        display: function (element, value) {
+            if (element) {
+                element.visPropOld.visible = value;
+            }
+        },
+
         /**
          * Shows a hidden element on the canvas; Only a stub, requires implementation in the derived renderer.
+         *
+         * Please use JXG.AbstractRenderer#display instead
          * @param {JXG.GeometryElement} element Reference to the object that has to appear.
          * @see JXG.AbstractRenderer#hide
+         * @deprecated
          */
         show: function (element) { /* stub */ },
 
         /**
          * Hides an element on the canvas; Only a stub, requires implementation in the derived renderer.
+         *
+         * Please use JXG.AbstractRenderer#display instead
          * @param {JXG.GeometryElement} element Reference to the geometry element that has to disappear.
          * @see JXG.AbstractRenderer#show
+         * @deprecated
          */
         hide: function (element) { /* stub */ },
 
@@ -539,6 +556,16 @@ define(['jxg', 'renderer/abstract'], function (JXG, AbstractRenderer) {
          */
         updateGradient: function (element) { /* stub */ },
 
+        /**
+         * Sets the transition duration (in milliseconds) for fill color and stroke
+         * color and opacity.
+         * @param {JXG.GeometryElement} element Reference of the object that wants a
+         *         new transition duration.
+         * @param {Number} duration (Optional) duration in milliseconds. If not given,
+         *        element.visProp.transitionDuration is taken. This is the default.
+         */
+        setObjectTransition: function (element, duration) { /* stub */ },
+
         /**
          * Sets an objects fill color.
          * @param {JXG.GeometryElement} element Reference of the object that wants a new fill color.
