@@ -12,6 +12,19 @@ JXG.Options = JXG.merge(JXG.Options, {
 
     board: {
         minimizeReflow: 'all', // 'svg', 'all', 'none'
+        zoom: {
+            enabled: true,
+            wheel: true,
+            needShift: true,
+            pinchHorizontal: false,
+            pinchVertical: false,
+        },
+        pan: {
+            needShift: true,
+            needTwoFingers: true,
+            enabled: true
+        },
+
         selection: {
             enabled: false
         }
@@ -52,6 +65,10 @@ JXG.Options = JXG.merge(JXG.Options, {
         strokeOpacity: 0.9
     },
 
+    elements: {
+        transitionDuration: 170
+    },
+
     glider : {
         strokeColor: 'orange',
         fillColor: 'orange',
@@ -77,6 +94,15 @@ JXG.Options = JXG.merge(JXG.Options, {
         opacity: 1
     },
 
+    perpendicularsegment: {
+        point: {
+            visible: true,
+            strokeColor: '#808080',
+            fillColor: '#808080',
+            opacity: 1
+        }
+    },
+
     point: {
         size: 4,
         fillColor:   '#cc0000',
@@ -183,6 +209,35 @@ JXG.Options = JXG.merge(JXG.Options, {
         }
     },
 
+    slopetriangle: {
+        glider: {
+            strokeColor: '#808080',
+            fillColor: '#808080',
+            opacity: 1,
+            visible: true
+        },
+
+        /*
+        baseline: {
+            visible: false
+        },
+
+        basepoint: {
+            visible: true
+        },
+
+        tangent: {
+            visible: false
+        },
+        */
+        toppoint: {
+            strokeColor: '#808080',
+            fillColor: '#808080',
+            opacity: 1,
+            visible: true
+        },
+    },
+
     tapemeasure: {
         strokeColor: '#000000',
         strokeWidth: 2,
