@@ -10,20 +10,20 @@
     This file is part of JSXGraph.
 
     JSXGraph is free software dual licensed under the GNU LGPL or MIT License.
-    
+
     You can redistribute it and/or modify it under the terms of the
-    
+
       * GNU Lesser General Public License as published by
         the Free Software Foundation, either version 3 of the License, or
         (at your option) any later version
       OR
       * MIT License: https://github.com/jsxgraph/jsxgraph/blob/master/LICENSE.MIT
-    
+
     JSXGraph is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU Lesser General Public License for more details.
-    
+
     You should have received a copy of the GNU Lesser General Public License and
     the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
     and <http://opensource.org/licenses/MIT/>.
@@ -257,7 +257,7 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
         var color_string, channels, re, processor, bits, i,
             r, g, b,
             values = color,
-            testFloat = false;
+            testFloat;
 
         if (!Type.exists(color)) {
             return [];
@@ -269,6 +269,7 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
 
         color_string = values;
 
+        testFloat = false;
         if (Type.isArray(color_string)) {
             for (i = 0; i < 3; i++) {
                 testFloat = testFloat || /\./.test(values[i].toString());
@@ -384,14 +385,12 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
     /**
      * Converts a valid HTML/CSS color string from the '#rrggbb' format into the 'rgb(r, g, b)' format.
      * @param {String} hex A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', or 'black'
+     * @deprecated Use {@link JXG#rgb2css} instead.
      * @returns {String} A 'rgb(r, g, b)' formatted string
      */
     JXG.hex2rgb = function (hex) {
-        var r;
-
-        r = JXG.rgbParser(hex);
-
-        return 'rgb(' + r[0] + ', ' + r[1] + ', ' + r[2] + ')';
+        JXG.deprecated('JXG.hex2rgb()', 'JXG.rgb2css()');
+        return JXG.rgb2css(hex);
     };
 
     /**
@@ -402,7 +401,7 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
      * @param {Number} H value between 0 and 360
      * @param {Number} S value between 0.0 (shade of gray) to 1.0 (pure color)
      * @param {Number} V value between 0.0 (black) to 1.0 (white)
-     * @return {String} RGB color string
+     * @returns {String} RGB color string
      */
     JXG.hsv2rgb = function (H, S, V) {
         var R, G, B, f, i, hTemp, p, q, t;
@@ -551,7 +550,9 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
     JXG.rgb2LMS = function (color, ag, ab) {
         var r, g, b, l, m, s, ret,
             // constants
-            matrix = [[0.05059983, 0.08585369, 0.00952420], [0.01893033, 0.08925308, 0.01370054], [0.00292202, 0.00975732, 0.07145979]];
+            matrix = [[0.05059983, 0.08585369, 0.00952420],
+                [0.01893033, 0.08925308, 0.01370054],
+                [0.00292202, 0.00975732, 0.07145979]];
 
         r = JXG.rgbParser(color, ag, ab);
         g = r[1];
@@ -586,7 +587,9 @@ define(['jxg', 'utils/type', 'math/math'], function (JXG, Type, Mat) {
     JXG.LMS2rgb = function (l, m, s) {
         var r, g, b, ret,
             // constants
-            matrix = [[30.830854, -29.832659, 1.610474], [-6.481468, 17.715578, -2.532642], [-0.375690, -1.199062, 14.273846]],
+            matrix = [[30.830854, -29.832659, 1.610474],
+                [-6.481468, 17.715578, -2.532642],
+                [-0.375690, -1.199062, 14.273846]],
 
             // re-gamma, inspired by GIMP modules/display-filter-color-blind.c:
             // Copyright (C) 2002-2003 Michael Natterer <mitch@gimp.org>,
