@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2017
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -131,7 +131,7 @@ define([
          * @param v
          */
         isObject: function (v) {
-            return typeof v === 'object' && !JXG.isArray(v);
+            return typeof v === 'object' && !this.isArray(v);
         },
 
         /**
@@ -189,7 +189,7 @@ define([
          * @returns <tt>d</tt>, if <tt>v</tt> is undefined or null.
          */
         def: function (v, d) {
-            if (JXG.exists(v)) {
+            if (this.exists(v)) {
                 return v;
             }
 
@@ -202,7 +202,7 @@ define([
          * @returns {Boolean} String typed boolean value converted to boolean.
          */
         str2Bool: function (s) {
-            if (!JXG.exists(s)) {
+            if (!this.exists(s)) {
                 return true;
             }
 
@@ -210,7 +210,7 @@ define([
                 return s;
             }
 
-            if (JXG.isString(s)) {
+            if (this.isString(s)) {
                 return (s.toLowerCase() === 'true');
             }
 
@@ -254,7 +254,7 @@ define([
         createFunction: function (term, board, variableName, evalGeonext) {
             var f = null;
 
-            if ((!JXG.exists(evalGeonext) || evalGeonext) && JXG.isString(term)) {
+            if ((!this.exists(evalGeonext) || evalGeonext) && this.isString(term)) {
                 // Convert GEONExT syntax into  JavaScript syntax
                 //newTerm = JXG.GeonextParser.geonext2JS(term, board);
                 //return new Function(variableName,'return ' + newTerm + ';');
@@ -262,14 +262,14 @@ define([
                 //term = JXG.GeonextParser.replaceNameById(term, board);
                 //term = JXG.GeonextParser.geonext2JS(term, board);
                 f = board.jc.snippet(term, true, variableName, true);
-            } else if (JXG.isFunction(term)) {
+            } else if (this.isFunction(term)) {
                 f = term;
-            } else if (JXG.isNumber(term)) {
+            } else if (this.isNumber(term)) {
                 /** @ignore */
                 f = function () {
                     return term;
                 };
-            } else if (JXG.isString(term)) {
+            } else if (this.isString(term)) {
                 // In case of string function like fontsize
                 /** @ignore */
                 f = function () {
@@ -314,7 +314,7 @@ define([
                 parents = [parents];
             }
             len = parents.length;
-            if (JXG.exists(attrArray)) {
+            if (this.exists(attrArray)) {
                 lenAttr = attrArray.length;
             }
             if (lenAttr === 0) {
@@ -364,7 +364,7 @@ define([
          * @returns If <tt>val</tt> is a function, it is evaluated and the result is returned. Otherwise <tt>val</tt> is returned.
          */
         evaluate: function (val) {
-            if (JXG.isFunction(val)) {
+            if (this.isFunction(val)) {
                 return val();
             }
 
@@ -380,7 +380,7 @@ define([
          * <tt>-1</tt> if the value was not found.
          */
         indexOf: function (array, value, sub) {
-            var i, s = JXG.exists(sub);
+            var i, s = this.exists(sub);
 
             if (Array.indexOf && !s) {
                 return array.indexOf(value);
@@ -450,8 +450,12 @@ define([
             }
 
             for (i = 0; i < arr.length; i++) {
-                isArray = JXG.isArray(arr[i]);
+                isArray = this.isArray(arr[i]);
 
+                if (!this.exists(arr[i])) {
+                    arr[i] = '';
+                    continue;
+                }
                 for (j = i + 1; j < arr.length; j++) {
                     if (isArray && JXG.cmpArrays(arr[i], arr[j])) {
                         arr[i] = [];
@@ -464,14 +468,14 @@ define([
             j = 0;
 
             for (i = 0; i < arr.length; i++) {
-                isArray = JXG.isArray(arr[i]);
+                isArray = this.isArray(arr[i]);
 
                 if (!isArray && arr[i] !== '') {
                     ret[j] = arr[i];
-                    j += 1;
+                    j++;
                 } else if (isArray && arr[i].length !== 0) {
                     ret[j] = (arr[i].slice(0));
-                    j += 1;
+                    j++;
                 }
             }
 
@@ -576,20 +580,96 @@ define([
         trunc: function (n, p) {
             p = JXG.def(p, 0);
 
-            /*jslint bitwise: true*/
+            return this.toFixed(n, p);
+        },
 
-            /*
-             * The performance gain of this bitwise trick is marginal and the behavior
-             * is different from toFixed: toFixed rounds, the bitweise operation truncateds
-             */
-            //if (p === 0) {
-            //    n = ~n;
-            //    n = ~n;
-            //} else {
-            n = n.toFixed(p);
-            //}
+        /**
+    	 * Decimal adjustment of a number.
+    	 * From https://developer.mozilla.org/de/docs/Web/JavaScript/Reference/Global_Objects/Math/round
+    	 *
+    	 * @param	{String}	type	The type of adjustment.
+    	 * @param	{Number}	value	The number.
+    	 * @param	{Number}	exp		The exponent (the 10 logarithm of the adjustment base).
+    	 * @returns	{Number}			The adjusted value.
+    	 *
+    	 * @private
+    	 */
+    	_decimalAdjust: function(type, value, exp) {
+    		// If the exp is undefined or zero...
+    		if (typeof exp === 'undefined' || +exp === 0) {
+    			return Math[type](value);
+    		}
 
-            return n;
+    		value = +value;
+    		exp = +exp;
+    		// If the value is not a number or the exp is not an integer...
+    		if (isNaN(value) || !(typeof exp === 'number' && exp % 1 === 0)) {
+    			return NaN;
+    		}
+
+            // Shift
+    		value = value.toString().split('e');
+    		value = Math[type](+(value[0] + 'e' + (value[1] ? (+value[1] - exp) : -exp)));
+
+    		// Shift back
+    		value = value.toString().split('e');
+    		return +(value[0] + 'e' + (value[1] ? (+value[1] + exp) : exp));
+    	},
+
+        /**
+         * Round a number to given number of decimal digits.
+         *
+         * Example: JXG._toFixed(3.14159, -2) gives 3.14
+         * @param  {Number} value Number to be rounded
+         * @param  {Number} exp   Number of decimal digits given as negative exponent
+         * @return {Number}       Rounded number.
+         *
+         * @private
+         */
+    	_round10: function(value, exp) {
+    		return this._decimalAdjust('round', value, exp);
+		},
+
+        /**
+         * "Floor" a number to given number of decimal digits.
+         *
+         * Example: JXG._toFixed(3.14159, -2) gives 3.14
+         * @param  {Number} value Number to be floored
+         * @param  {Number} exp   Number of decimal digits given as negative exponent
+         * @return {Number}       "Floored" number.
+         *
+         * @private
+         */
+        _floor10: function(value, exp) {
+    		return this._decimalAdjust('floor', value, exp);
+    	},
+
+        /**
+         * "Ceil" a number to given number of decimal digits.
+         *
+         * Example: JXG._toFixed(3.14159, -2) gives 3.15
+         * @param  {Number} value Number to be ceiled
+         * @param  {Number} exp   Number of decimal digits given as negative exponent
+         * @return {Number}       "Ceiled" number.
+         *
+         * @private
+         */
+        _ceil10: function(value, exp) {
+    		return this._decimalAdjust('ceil', value, exp);
+    	},
+
+        /**
+         * Replacement of the default toFixed() method.
+         * It does a correct rounding (independent of the browser) and
+         * returns "0.00" for toFixed(-0.000001, 2) instead of "-0.00" which
+         * is returned by JavaScript's toFixed()
+         *
+         * @param  {Number} num       Number tp be rounded
+         * @param  {Number} precision Decimal digits
+         * @return {String}           Rounded number is returned as string
+         */
+        toFixed: function(num, precision) {
+            return this._round10(num, -precision).toFixed(precision);
         },
 
         /**
@@ -598,18 +678,19 @@ define([
          * @returns {Number}
          */
         autoDigits: function (val) {
-            var x = Math.abs(val);
+            var x = Math.abs(val),
+                str;
 
             if (x > 0.1) {
-                x = val.toFixed(2);
+                str = this.toFixed(val, 2);
             } else if (x >= 0.01) {
-                x = val.toFixed(4);
+                str = this.toFixed(val, 4);
             } else if (x >= 0.0001) {
-                x = val.toFixed(6);
+                str = this.toFixed(val, 6);
             } else {
-                x = val;
+                str = val;
             }
-            return x;
+            return str;
         },
 
         /**
@@ -682,7 +763,7 @@ define([
 
         /**
          * Recursively merges obj2 into obj1. Contrary to {@link JXG#deepCopy} this won't create a new object
-         * but instead will
+         * but instead will overwrite obj1.
          * @param {Object} obj1
          * @param {Object} obj2
          * @returns {Object}
@@ -776,7 +857,7 @@ define([
 
                     prop = obj2[i];
                     if (typeof prop === 'object') {
-                        if (JXG.isArray(prop) || !JXG.exists(c[i2])) {
+                        if (this.isArray(prop) || !this.exists(c[i2])) {
                             c[i2] = this.deepCopy(prop);
                         } else {
                             c[i2] = this.deepCopy(c[i2], prop, toLower);
@@ -792,7 +873,7 @@ define([
 
         /**
          * Generates an attributes object that is filled with default values from the Options object
-         * and overwritten by the user speciified attributes.
+         * and overwritten by the user specified attributes.
          * @param {Object} attributes user specified attributes
          * @param {Object} options defaults options
          * @param {String} s variable number of strings, e.g. 'slider', subtype 'point1'.
@@ -830,7 +911,7 @@ define([
             o = options;
             isAvail = true;
             for (i = 2; i < len; i++) {
-                if (JXG.exists(o[arguments[i]])) {
+                if (this.exists(o[arguments[i]])) {
                     o = o[arguments[i]];
                 } else {
                     isAvail = false;
@@ -845,7 +926,7 @@ define([
             o = attributes;
             isAvail = true;
             for (i = 3; i < len; i++) {
-                if (JXG.exists(o[arguments[i]])) {
+                if (this.exists(o[arguments[i]])) {
                     o = o[arguments[i]];
                 } else {
                     isAvail = false;
@@ -860,14 +941,14 @@ define([
             o = options;
             isAvail = true;
             for (i = 2; i < len; i++) {
-                if (JXG.exists(o[arguments[i]])) {
+                if (this.exists(o[arguments[i]])) {
                     o = o[arguments[i]];
                 } else {
                     isAvail = false;
                     break;
                 }
             }
-            if (isAvail && JXG.exists(o.label)) {
+            if (isAvail && this.exists(o.label)) {
                 a.label =  JXG.deepCopy(o.label, a.label);
             }
             a.label = JXG.deepCopy(options.label, a.label);
@@ -921,7 +1002,7 @@ define([
                 if (obj) {
                     list = [];
 
-                    if (JXG.isArray(obj)) {
+                    if (this.isArray(obj)) {
                         for (i = 0; i < obj.length; i++) {
                             list.push(JXG.toJSON(obj[i], noquote));
                         }
@@ -965,18 +1046,23 @@ define([
          */
         clearVisPropOld: function (el) {
             el.visPropOld = {
+                cssclass: '',
+                cssdefaultstyle: '',
+                cssstyle: '',
+                fillcolor: '',
+                fillopacity: '',
+                firstarrow: false,
+                fontsize: -1,
+                lastarrow: false,
+                left: -100000,
+                linecap: '',
+                shadow: false,
                 strokecolor: '',
                 strokeopacity: '',
                 strokewidth: '',
-                fillcolor: '',
-                fillopacity: '',
-                shadow: false,
-                firstarrow: false,
-                lastarrow: false,
-                cssclass: '',
-                fontsize: -1,
-                left: -100000,
-                top: -100000
+                transitionduration: 0,
+                top: -100000,
+                visible: null,
             };
 
             return el;
@@ -1148,7 +1234,7 @@ define([
          */
         evalSlider: function (s) {
             if (s && s.type === Const.OBJECT_TYPE_GLIDER && typeof s.Value === 'function') {
-                s = s.Value();
+                return s.Value();
             }
 
             return s;
